@@ -59,6 +59,8 @@ function searchApachectl () {
 			$APACHECTL = "/usr/local/sbin/apachectl2";
 		}else if(file_exists("/usr/local/sbin/apachectl")){
                 	 $APACHECTL = "/usr/local/sbin/apachectl";
+		}else if(file_exists("/usr/sbin/apachectl")){
+                	 $APACHECTL = "/usr/sbin/apachectl";
 		}
 	}else{
 		if(file_exists("/usr/sbin/apachectl")){
@@ -93,7 +95,10 @@ function checkLockFlag () {
 	if($cronjob_table_content["lock_flag"] != "finished"){
 		echo "DB flag says that last cron job is not finished: exiting.\n
 If no cronjob is running, then please please type:\n
-mysql -uroot -Ddtc -p --execute=\"UPDATE $pro_mysql_cronjob_table SET lock_flag='finished';\"\n";
+mysql -uroot -Ddtc -p --execute=\"UPDATE $pro_mysql_cronjob_table SET lock_flag='finished';\"\n
+If runing Debian, you can directly run:\n
+mysql --defaults-file=/etc/mysql/debian.cnf -Ddtc --execute=\"UPDATE cron_job SET lock_flag='finished';\"\n
+";
 		die("Exiting NOW!");
 	}
 	echo "Setting-up lock flag\n";
@@ -262,6 +267,20 @@ function updateAllListWebArchive(){
 		exec($updatewa);
 	}
 }
+
+function get_apache_pid() {
+	global $conf_generated_file_path;
+	$pid = @file_get_contents("$conf_generated_file_path/apache.pid");
+	if ($pid) { return (int) $pid; }
+}
+
+if( !function_exists("posix_kill")){
+	function posix_kill($pid, $sig=1){
+		system('kill -'.$sig.' '. $pid, $st); 
+		return !$st;
+	}
+}
+
 function restartApache () {
 	global $conf_generated_file_path;
 	global $conf_dtc_system_username;
@@ -286,46 +305,48 @@ function restartApache () {
 	echo "Testing apache conf\n";
 	exec ("$APACHECTL configtest 2>&1 | grep -qF 'Syntax OK'", $plop, $return_var);
 	if($return_var == false){
-		echo "Config is OK : restarting Apache\n";
-		echo "$APACHECTL stop\n";
-		system("$APACHECTL stop");
-		sleep(1);
-		$ctl_retry = 0;
-		while( is_file("$conf_generated_file_path/apache.pid") && $ctl_retry++ < 12){
-			echo "Warning: apache not stoped, will check and maybe retry in 2 seconds...";
-			echo "2...";sleep(1);echo "1...";sleep(1);echo "0";
-			clearstatcache();
-			if( is_file("$conf_generated_file_path/apache.pid") ){
-				echo "...retrying!\n";
-				$ctl_return = system("$APACHECTL stop", $return_var);
-			}else{
-				echo "...ok!\n";
+// 		this code works fine without interrupting the service.  it might take a while until all apache processes have the new configuration (config reload for each apache process waits until the request they are serving is finished), but what we care is that the NEW clients connecting will have it, and that is true in this case
+// 		root@xen011106:~# kill -HUP 29153
+// 		root@xen011106:~# [Sun Aug 31 12:44:53 2008] [notice] SIGHUP received.  Attempting to restart
+// 		[Sun Aug 31 12:44:53 2008] [notice] Apache/2.2.3 (Debian) PHP/5.2.0-8+etch11 configured -- resuming normal operations
+		$pid = get_apache_pid();
+		if ($pid) {
+			echo "Apache PID: $pid\n";
+		 	$ret = posix_kill($pid,1);
+			if ($ret) print "Apache successfully SIGHUPped -- configuration should have been reloaded\n";
+		}
+		else { $ret = FALSE; /* so brutal restart takes place */ }
+		if ($ret === FALSE) {
+			echo "Apache is not running -- switching to restart mode\n";
+			$pid = get_apache_pid();
+			if ($pid && posix_kill($pid,0)) {
+				/* apache is running, we stop it */
+				$ret = system("$APACHECTL stop");
+				if ($ret != 0) { echo "$APACHECTL stop failed with return status $ret\n"; }
+				/* wait 20 seconds or until it is down */
+				for ($m = 0; $m < 80 && posix_kill($pid,0); $m++) { usleep(250000); }
+				if (posix_kill($pid,0)) { echo "error: apache still running with PID $pid\n"; }
+			}
+			/* we now start Apache */
+			for ($x = 0; $x < 10; $x++) {
+				$ret = system("$APACHECTL start");
+				if ($ret != 0) echo "$APACHECTL start failed with return status $ret\n";
+				$suc = 0;
+				for ($m = 0; $m < 80; $m++) { /* wait 20 seconds or until it is up */
+					$pid = get_apache_pid();
+					if (($pid) && posix_kill($pid,0)) { /* apache is now running */
+						echo "Apache restarted\n";
+						$suc = 1; break;
+					}
+					else { usleep(250000); }
+				}
+				if ($suc == 1) { break; }
+				$pid = get_apache_pid();
+				if (!$pid || !posix_kill($pid,0)) { echo "error: apache never started\n"; }
 			}
 		}
-		clearstatcache();
-
-		$ctl_return = system("$APACHECTL start");
-		clearstatcache();
-		$ctl_retry = 0;
-		// Check that apache is really started, because experience showed sometimes it's not !!!
-		//while( strstr($ctl_return,"httpd started") == false && $ctl_retry++ < 15){
-		// This new version should work on OS where apachectl start is quiet
-		while( !is_file("$conf_generated_file_path/apache.pid") && $ctl_retry++ < 12){
-			echo "Warning: apache not started, will check and maybe retry in 2 seconds...";
-			echo "2...";sleep(1);echo "1...";sleep(1);echo "0";
-			clearstatcache();
-			if( !is_file("$conf_generated_file_path/apache.pid") ){
-				echo "...retrying!\n";
-				$ctl_return = system("$APACHECTL start", $return_var);
-			}else{
-				echo "...ok!\n";
-			}
-		}
-		// change to graceful apache restart, rather than a hard stop and start
-		// WARNING !!! Experience showed that it doesn't work sometimes !!!
-		//system("$APACHECTL graceful");
 	}else{
-		echo "Config not OK : I can't reload apache !!!\n";
+		echo "Config not OK - apache can't be restarted\n";
 	}
 }
 
@@ -417,6 +438,12 @@ function cronMailSystem () {
 			system("chown $conf_dtc_system_username $conf_generated_file_path/postfix_relay_recipients");
 		}
 	}
+	/* Didnt want it to put to seperate function, because I think its fit well in mail system's cronjob */
+	if ($cronjob_table_content["gen_fetchmail"] == "yes") {
+	    echo "Generating fetchmailrc";
+	    fetchmail_generate();
+	}
+	
 	if($cronjob_table_content["qmail_newu"] == "yes"){
 		echo "Starting qmail-newu\n";
 		switch($conf_mta_type){
@@ -444,6 +471,9 @@ function cronMailSystem () {
 			if($conf_unix_type == "gentoo" && file_exists("/etc/init.d/postfix")) {
 				$PATH_POSTFIX_SCRIPT = "/usr/sbin/postfix";
 			}
+			if ($conf_unix_type == "bsd" && file_exists("/usr/local/etc/rc.d/postfix")) {
+				$PATH_POSTFIX_SCRIPT = "/usr/local/sbin/postfix";
+			}
 			system("$PATH_POSTFIX_SCRIPT reload");
 
 			$PATH_POSTSUPER = "/usr/sbin/postsuper";
@@ -457,7 +487,7 @@ function cronMailSystem () {
 
                         // first stop queue processing in postfix
                         echo "Stopping postfix queue...\n";
-                        system("$PATH_POSTSUPER -h ALL");
+                        system("$PATH_POSTSUPER -h ALL 2&>1");
 
 			echo "Reloading amavis\n";
 			if( file_exists ("/etc/init.d/amavis") ){
@@ -472,11 +502,13 @@ function cronMailSystem () {
 
 			if( file_exists ("/etc/init.d/dkimproxy") ){
 				echo "Reloading dkfilter to reload it's domains...\n";
-				system("/etc/init.d/dkimproxy force-reload");
+				system("/etc/init.d/dkimproxy stop");
+				sleep(1);
+				system("/etc/init.d/dkimproxy start");
 			}
 			
 			echo "Starting postfix queue...\n";
-                        system("$PATH_POSTSUPER -H ALL");
+                        system("$PATH_POSTSUPER -H ALL 2&>1");
 
 			echo "Flushing the queue now, to make sure we have some mail delivery happening after amavisd restart...\n";
                         system("$PATH_POSTFIX_SCRIPT flush");
@@ -513,7 +545,7 @@ function checkNamedCronService () {
 	// First, see if we have to regenerate deamons files //
 	///////////////////////////////////////////////////////
 	if($cronjob_table_content["gen_named"] == "yes"){
-		echo "Generating Named zonefile\n";
+		echo "Generating Named zonefile ... this may take a while\n";
 		named_generate();
 		system("chgrp $conf_dtc_system_groupname $conf_generated_file_path/named.conf $conf_generated_file_path/named.slavezones.conf");
 		system("chmod 770 $conf_generated_file_path/named.conf $conf_generated_file_path/named.slavezones.conf");
@@ -564,6 +596,49 @@ function checkApacheCronService () {
 	}
 }
 
+function checkNagiosCronService () {
+	global $conf_nagios_host;
+	global $conf_nagios_username;
+	global $conf_nagios_config_file_path;
+	global $conf_nagios_restart_command;
+
+	if ( 	! $conf_nagios_host or
+		! $conf_nagios_username or  
+		! $conf_nagios_config_file_path or  
+		! $conf_nagios_restart_command ) return;
+
+	$cronjob_table_content = getCronFlags();
+	if($cronjob_table_content["gen_nagios"] == "yes"){
+		echo "Generating Nagios configuration\n";
+		$config = nagios_generate();
+		$tmpfile = tempnam("/somedirthatdoesntexist","newnagiosconfig");
+		file_put_contents($tmpfile,$config);
+
+		// FIXME: To work, this code requires that 1) the nagios monitor host be in the SSH keyring for the DTC user 2) the destination file be writable for the user DTC uses to log into the nagios monitor host.  We cannot do that from here.
+
+		$returnvar = 0;
+
+		echo "Copying Nagios configuration to monitor host\n";
+		system("scp -B $tmpfile $conf_nagios_username@$conf_nagios_host:$conf_nagios_config_file_path",$return_var);
+		if ($return_var) {
+			echo "Failed (return value $return_var) to install Nagios configuration in username@$conf_nagios_host:$conf_nagios_config_file_path";
+			unlink($tmpfile);
+			return;
+		}
+
+		echo "Reloading Nagios configuration\n";
+		system("ssh -o 'BatchMode yes' $conf_nagios_username@$conf_nagios_host $conf_nagios_restart_command",$return_var);
+		if ($return_var) {
+			echo "Failed (return value $return_var) to reload Nagios configuration in $conf_nagios_host using command $conf_nagios_restart_command";
+			unlink($tmpfile);
+			return;
+		}
+
+		unlink($tmpfile);
+		markCronflagOk ("gen_nagios='no'");
+	}
+}
+
 function checkWebalizerCronService () {
 	$cronjob_table_content = getCronFlags();
 	if($cronjob_table_content["gen_webalizer"] == "yes"){
@@ -596,6 +671,7 @@ cronMailSystem();
 checkPop3dStarted();
 checkSSHCronService();
 checkApacheCronService();
+checkNagiosCronService();
 $cronjob_table_content = getCronFlags();
 if($cronjob_table_content["gen_backup"] == "yes"){
 	echo "Generating backup script\n";
