@@ -28,7 +28,7 @@ $dtc_database = array(
 			"ob_head" => "varchar(64) NOT NULL ",
 			"ob_tail" => "varchar(64) NOT NULL ",
 			"ob_next" => "varchar(64) NOT NULL ",
-			"last_used_lang" => "varchar(32) NOT NULL default 'en_US'",
+			"last_used_lang" => "varchar(32) NOT NULL default 'en_US.UTF-8'",
 			"max_ssh" => "int(12) NOT NULL default '3' "
 			),
 		"primary" => "(adm_login)",
@@ -78,7 +78,8 @@ $dtc_database = array(
 			"dollar" => "decimal(9,2) NOT NULL default '0.00' ",
 			"disk_quota_mb" => "int(9) NOT NULL default '0' ",
 			"bw_quota_per_month_gb" => "int(9) NOT NULL default '0' ",
-			"expire" => "date NOT NULL default '0000-00-00' "
+			"expire" => "date NOT NULL default '0000-00-00' ",
+			"active" => "enum('yes','no') NOT NULL default 'yes'"
 			),
 		"primary" => "(id)",
 		"keys" => array(
@@ -164,8 +165,10 @@ $dtc_database = array(
 			"named_slavefile_path" => "varchar(255) NOT NULL default 'named.slavezones.conf' ",
 			"named_slavezonefiles_path" => "varchar(255) NOT NULL default 'slave_zones' ",
 			"named_zonefiles_path" => "varchar(255) NOT NULL default 'zones' ",
-			"send_passwords_in_emails" => "enum('yes','no') NOT NULL default 'no'",
 			"autogen_default_subdomains" => "enum('yes','no') NOT NULL default 'yes'",
+			"autogen_subdomain_list" => "varchar(255) NOT NULL default 'pop|imap|mail|smtp|ftp'",
+			"autogen_webmail_alias" => "enum('yes','no') NOT NULL default 'yes'",
+			"autogen_webmail_type" => "enum('squirrelmail','roundcube') NOT NULL default 'squirrelmail'",
 			"backup_script_path" => "varchar(255) NOT NULL default 'backup.bash' ",
 			"bakcup_path" => "varchar(255) NOT NULL default '/mnt/backup' ",
 			"webalizer_stats_script_path" => "varchar(255) NOT NULL default 'webalizer.bash' ",
@@ -183,8 +186,6 @@ $dtc_database = array(
 			"hide_password" => "enum('yes','no') NOT NULL default 'no' ",
 			"session_expir_minute" => "int(9) NOT NULL default '10' ",
 			"dns_type" => "enum('bind','djb') NOT NULL default 'bind' ",
-			"root_admin_random_pass" => "varchar(128) NOT NULL ",
-			"pass_expire" => "int(12) NOT NULL default '1' ",
 			"srs_user" => "varchar(128) NOT NULL ",
 			"srs_live_key" => "varchar(255) NOT NULL ",
 			"srs_test_key" => "varchar(255) NOT NULL ",
@@ -212,6 +213,7 @@ $dtc_database = array(
 			"dtc_system_gid" => "varchar (16) NOT NULL default '65534'",
 			"dtc_system_groupname" => "varchar (64) NOT NULL default 'nogroup'",
 			"selling_conditions_url" => "varchar (255) NOT NULL default 'none'",
+			"user_mysql_prepend_admin_name" => "enum('yes','no') NOT NULL default 'no'",
 			"user_mysql_type" => "enum('localhost','distant') NOT NULL default 'localhost'",
 			"user_mysql_host" => "varchar (255) NOT NULL default 'localhost'",
 			"user_mysql_root_login" => "varchar (255) NOT NULL default 'none'",
@@ -223,10 +225,27 @@ $dtc_database = array(
 			"use_cyrus" => "enum('yes','no') NOT NULL default 'no' ",
 			"use_amavis" => "enum('yes','no') NOT NULL default 'yes'",
 			"use_clamav" => "enum('yes','no') NOT NULL default 'yes'",
+			"use_advanced_lists_tunables" => "enum('yes','no') NOT NULL default 'no'",
 			"use_webalizer" => "enum('yes','no') NOT NULL default 'yes'",
 			"use_awstats" => "enum('yes','no') NOT NULL default 'no'",
 			"use_visitors" => "enum('yes','no') NOT NULL default 'no'",
-			"message_subject_header" => "varchar (255) NOT NULL default '[DTC]'"
+			"message_subject_header" => "varchar (255) NOT NULL default '[DTC]'",
+			"apache_directoryindex" => "varchar (255) NOT NULL default 'index.php index.cgi index.pl index.htm index.html index.php4'",
+			"named_soa_refresh" => "varchar (16) NOT NULL default '2H'",
+			"named_soa_retry" => "varchar (16) NOT NULL default '60M'",
+			"named_soa_expire" => "varchar (16) NOT NULL default '1W'",
+			"named_soa_default_ttl" => "varchar (16) NOT NULL default '24H'",
+			"provide_own_domain_hosts" => "enum('yes','no') NOT NULL default 'no'",
+			"nagios_host" => "varchar(255) NOT NULL default ''",
+			"nagios_username" => "varchar(255) NOT NULL default ''",
+			"nagios_config_file_path" => "varchar(255) NOT NULL default ''",
+			"nagios_restart_command" => "varchar(255) NOT NULL default 'sudo /etc/init.d/nagios2 restart'",
+			"affiliate_return_domain" => "varchar(255) NOT NULL default 'www.example.com'",
+			"support_ticket_email" => "varchar(255) NOT NULL default 'support'",
+			"support_ticket_domain" => "varchar(255) NOT NULL default 'default'",
+			"all_customers_list_email" => "varchar(255) NOT NULL default 'support'",
+			"all_customers_list_domain" => "varchar(255) NOT NULL default 'default'"
+
 			),
 		"keys" => array(
 			"unicrow" => "(unicrow)"
@@ -242,6 +261,8 @@ $dtc_database = array(
 			"restart_apache" => "enum('yes','no') NOT NULL default 'no' ",
 			"gen_vhosts" => "enum('yes','no') NOT NULL default 'no' ",
 			"gen_named" => "enum('yes','no') NOT NULL default 'no' ",
+			"gen_reverse" => "enum('yes','no') NOT NULL default 'no'",
+			"gen_fetchmail" => "enum('yes','no') NOT NULL default 'no'",
 			"gen_qmail" => "enum('yes','no') NOT NULL default 'no' ",
 			"gen_webalizer" => "enum('yes','no') NOT NULL default 'no' ",
 			"gen_backup" => "enum('yes','no') NOT NULL default 'no' ",
@@ -271,6 +292,21 @@ $dtc_database = array(
 			"server_hostname" => "(server_hostname)"
 			)
 		),
+	"dedicated_ip" => array(
+		"vars" => array (
+			"id" => "int(11) NOT NULL auto_increment",
+			"dedicated_server_hostname" => "varchar(255) NOT NULL default ''",
+			"ip_addr" => "varchar(16) NOT NULL default ''",
+			"available" => "enum('yes','no') NOT NULL default 'yes'",
+			"rdns_addr" => "varchar(255) NOT NULL default 'gplhost.com'",
+			"rdns_regen" => "enum('yes','no') NOT NULL default 'yes'",
+			"ip_pool_id" => "int(11) NOT NULL default '0'"
+			),
+		"primary" => "(id)",
+		"unique" => array(
+				"ip_addr" => "(ip_addr)"
+                        )
+		),
 	"domain" => array(
 		"vars" => array(
 			"id" => "int(12) NOT NULL auto_increment",
@@ -279,6 +315,7 @@ $dtc_database = array(
 			"sbox_protect" => "enum('yes','no') default 'yes' ",
 			"owner" => "varchar(64) NOT NULL ",
 			"default_subdomain" => "varchar(64) NULL default 'www' ",
+			"default_sub_server_alias" => "enum('yes','no') default 'yes'",
 			"generate_flag" => "enum('yes','no') NOT NULL default 'yes' ",
 			"quota" => "bigint(20) NOT NULL default '50' ",
 			"max_email" => "int(11) NOT NULL default '9' ",
@@ -300,6 +337,7 @@ $dtc_database = array(
 			"txt_root_entry2" => "varchar(128) NOT NULL default 'This domain is hosted using Domain Technologie Control http://www.gplhost.com/software-dtc.html' ",
 			"catchall_email" => "varchar(128) NOT NULL ",
 			"domain_parking" => "varchar(255) NOT NULL default 'no-parking' ",
+			"domain_parking_type" => "enum('redirect','same_docroot','serveralias') NOT NULL default 'redirect'",
 			"registrar_password" => "varchar(255) NOT NULL ",
 			"ttl" => "int NULL default '7200' ",
 			"stats_login" => "varchar(32) NOT NULL default ''",
@@ -544,6 +582,23 @@ $dtc_database = array(
                 	"vhost" => "(vhost,month,year,domain)"
 			)
 		),
+	"ip_pool" => array (
+		"vars" => array(
+			"id" => "int(11) NOT NULL auto_increment",
+			"location" => "varchar(255) NOT NULL default ''",
+			"ip_addr" => "varchar(16) NOT NULL default ''",
+			"netmask" => "varchar(16) NOT NULL default ''",
+			"gateway" => "varchar(16) NOT NULL default ''",
+			"broadcast" => "varchar(16) NOT NULL default ''",
+			"dns" => "varchar(16) NOT NULL default ''",
+			"zone_type" => "enum('support_ticket','ip_per_ip','one_zonefile') default 'one_zonefile'",
+			"custom_part" => "text NOT NULL"
+			),
+		"primary" => "(id)",
+		"unique" => array(
+			"ip_addr" => "(ip_addr)"
+			)
+		),
 	"ip_port_service" => array(
                 "vars" => array(
                         "id" => "int(11) NOT NULL auto_increment",
@@ -623,7 +678,7 @@ $dtc_database = array(
 			"date" => "date NOT NULL default '0000-00-00'",
 			"time" => "time NOT NULL default '00:00:00'",
 			"maxmind_output" => "text NOT NULL",
-			"last_used_lang" => "varchar(32) NOT NULL default 'en_US'",
+			"last_used_lang" => "varchar(32) NOT NULL default 'en_US.UTF-8'",
 			"add_service" => "enum('yes','no') NOT NULL default 'no'"
 			),
 		"primary" => "(id)"
@@ -651,7 +706,8 @@ $dtc_database = array(
 			"new_account" => "enum('yes','no') NOT NULL default 'no' ",
 			"product_id" => "int(11) NOT NULL default '0'",
 			"vat_rate" => "decimal(9,2) NOT NULL default '0.00'",
-			"vat_total" => "int(11) NOT NULL default '0'"
+			"vat_total" => "decimal(9,2) NOT NULL default '0'",
+			"hash_check_key" => "varchar(255) NOT NULL default '0'",
 			),
 		"primary" => "(id)",
 		"keys" => array(
@@ -732,6 +788,7 @@ $dtc_database = array(
 			"id" => "int(11) NOT NULL auto_increment",
 			"price_dollar" => "varchar(9) NOT NULL ",
 			"price_euro" => "varchar(9) NOT NULL ",
+			"setup_fee" => "decimal(15,2) NOT NULL default '0.00'",
 			"name" => "varchar(255) NOT NULL ",
 			"quota_disk" => "int(9) NOT NULL default '0' ",
 			"memory_size" => "int(9) NOT NULL default '48' ",
@@ -862,6 +919,7 @@ $dtc_database = array(
 			"unicrow" => "int(2) NOT NULL default '0' ",
 			"currency_symbol" => "varchar(16) NOT NULL default '$'",
 			"currency_letters" => "varchar(16) NOT NULL default 'USD'",
+
 			"use_paypal" => "enum('yes','no') NOT NULL default 'no' ",
 			"paypal_rate" => "float(6,2) NOT NULL default '0.00' ",
 			"paypal_flat" => "float(6,2) NOT NULL default '0.00' ",
@@ -869,18 +927,41 @@ $dtc_database = array(
 			"paypal_email" => "varchar(128) NOT NULL default 'palpay@gplhost.com' ",
 			"paypal_sandbox" => "enum('yes','no') NOT NULL default 'no' ",
 			"paypal_sandbox_email" => "varchar(255) NOT NULL ",
+			"paypal_validate_with" => "enum('total','mc_gross') NOT NULL default 'total'",
 			"use_paypal_recurring" => "enum('yes','no') NOT NULL default 'no' ",
+
+			"use_moneybookers" => "enum('yes','no') NOT NULL default 'no'",
+			"moneybookers_rate" => "float(6,2) NOT NULL default '0.00'",
+			"moneybookers_flat" => "float(6,2) NOT NULL default '0.00'",
+			"moneybookers_autovalidate" => "enum('yes','no') NOT NULL default 'yes'",
+			"moneybookers_email" => "varchar(128) NOT NULL default 'palpay@gplhost.com'",
+			"moneybookers_sandbox" => "enum('yes','no') NOT NULL default 'no'",
+			"moneybookers_sandbox_email" => "varchar(128) NOT NULL default ''",
+			"moneybookers_validate_with" => "enum('total','mc_gross') NOT NULL default 'total'",
+			"moneybookers_secret_word" => "varchar(128) NOT NULL default ''",
+
 			"use_enets" => "enum('yes','no') NOT NULL default 'no'",
 			"use_enets_test" => "enum('yes','no') NOT NULL default 'yes'",
 			"enets_mid_id" => "varchar(255) NOT NULL default ''",
 			"enets_test_mid_id" => "varchar(255) NOT NULL default ''",
 			"enets_rate" => "float(6,2) NOT NULL default '0.00'",
 			"use_maxmind" => "enum('yes','no') NOT NULL default 'no'",
+
 			"maxmind_login" => "varchar(255) NOT NULL default ''",
 			"maxmind_license_key" => "varchar(255) NOT NULL default ''",
+
 			"use_webmoney" => "enum('yes','no') NOT NULL default 'no'",
 			"webmoney_license_key" => "varchar(255) NOT NULL default ''",
-			"webmoney_wmz" => "varchar(255) NOT NULL default ''"
+			"webmoney_wmz" => "varchar(255) NOT NULL default ''",
+
+			"accept_cheques" => "enum('yes','no') NOT NULL default 'no'",
+			"cheques_flat_fees" => "float(6,2) NOT NULL default '0.00' ",
+			"cheques_to_label" => "varchar(255) NOT NULL default ''",
+			"cheques_send_address" => "text NOT NULL default ''",
+
+			"accept_wiretransfers" => "enum('yes','no') NOT NULL default 'no'",
+			"wiretransfers_flat_fees" => "float(6,2) NOT NULL default '0.00' ",
+			"wiretransfers_bank_details" => "text NOT NULL default ''"
 			),
 		"keys" => array(
 			"unicrow" => "(unicrow)"
@@ -903,6 +984,9 @@ $dtc_database = array(
 			"delivery_id_text" => "varchar(128) NOT NULL "
 			),
 		"primary" => "(id)",
+		"unique" => array(
+			"delivery_id_text" => "(delivery_id_text)"
+			),
 		"keys" => array(
 			"bounce_qp" => "(bounce_qp)",
 			"newmsg_id" => "(newmsg_id)"
@@ -954,6 +1038,22 @@ $dtc_database = array(
 			"p_addr" => "(ip_addr)"
 			),
 		),
+	"tik_admins" => array (
+		"vars" => array(
+			"id" => "int(11) NOT NULL auto_increment",
+			"pseudo" => "varchar(64) NOT NULL default ''",
+			"realname" => "varchar(64) NOT NULL default ''",
+			"email" => "varchar(128) NOT NULL default ''",
+			"available" => "enum('yes','no') NOT NULL default 'yes'",
+			"tikadm_pass" => "varchar(255) NOT NULL default ''",
+			"pass_next_req" => "varchar(128) NOT NULL default '0'",
+			"pass_expire" => "int(12) NOT NULL default '0'"
+			),
+		"primary" => "(id)",
+		"keys" => array(
+			"pseudo" => "(pseudo)"
+			)
+		),
 	"tik_queries" => array (
 		"vars" => array(
 			"id" => "int(11) NOT NULL auto_increment",
@@ -970,7 +1070,10 @@ $dtc_database = array(
 			"initial_ticket" => "enum('yes','no') NOT NULL default 'yes'",
 			"server_hostname" => "varchar(64) NOT NULL default ''",
 			"request_close" => "enum('yes','no') NOT NULL default 'no'",
-			"closed" => "enum('yes','no') NOT NULL default 'no'"
+			"customer_email" => "varchar(255) NOT NULL default ''",
+			"closed" => "enum('yes','no') NOT NULL default 'no'",
+			"hash" => "varchar(32) NOT NULL default ''",
+			"admin_name" => "varchar(256) NOT NULL default 'dtc'"
 			),
 		"primary" => "(id)",
 		"index" => array(
@@ -1004,7 +1107,17 @@ $dtc_database = array(
 			"product_id" => "int(9) NOT NULL default '0'",
 			"operatingsystem" => "varchar(64) NOT NULL default 'debian'",
 			"installed" => "enum('yes','no') NOT NULL default 'no'",
-			"bsdkernel" => "enum('normal','install') NOT NULL default 'normal'"
+			"bsdkernel" => "enum('normal','install') NOT NULL default 'normal'",
+			"vncpassword" => "varchar(64) NOT NULL default 'none'",
+			"howtoboot" => "varchar(256) NOT NULL default 'hdd'",
+			"monitoring_email" => "varchar(255) NOT NULL default ''",
+			"monitor_ping" => "enum('yes','no') NOT NULL default 'no'",
+			"monitor_ssh" => "enum('yes','no') NOT NULL default 'no'",
+			"monitor_http" => "enum('yes','no') NOT NULL default 'no'",
+			"monitor_smtp" => "enum('yes','no') NOT NULL default 'no'",
+			"monitor_pop3" => "enum('yes','no') NOT NULL default 'no'",
+			"monitor_imap4" => "enum('yes','no') NOT NULL default 'no'",
+			"monitor_ftp" => "enum('yes','no') NOT NULL default 'no'"
 			),
 		"unique" => array(
 			"vps_server_hostname" => "(vps_server_hostname,vps_xen_name)"
@@ -1020,6 +1133,8 @@ $dtc_database = array(
 			"vps_xen_name" => "varchar(64) NOT NULL default ''",
 			"ip_addr" => "varchar(16) NOT NULL default ''",
 			"rdns_addr" => "varchar(255) NOT NULL default 'gplhost.com'",
+			"rdns_regen" => "enum('yes','no') NOT NULL default 'yes'",
+			"ip_pool_id" => "int(11) NOT NULL default '0'",
 			"available" => "enum('yes','no') NOT NULL default 'yes'"
 			),
 		"unique" => array(
