@@ -2,17 +2,11 @@
 
 function productManager(){
         global $pro_mysql_product_table;
+        global $secpayconf_currency_symbol;
 
-	// Build the product ID popup
-        $qp = "SELECT id FROM $pro_mysql_product_table WHERE renew_prod_id='0'";
-        $rp = mysql_query($qp)or die("Cannot query \"$qp\" !!! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
-        $np = mysql_num_rows($rp);
-        $renew_id_popup = array();
-        $renew_id_popup[] = 0;
-	for($j=0;$j<$np;$j++){
-		$ap = mysql_fetch_array($rp);
-		$renew_id_popup[] = $ap["id"];
-	}
+        if(!isset($secpayconf_currency_symbol)){
+        	get_secpay_conf();
+        }
 
         $dsc = array(
         	"table_name" => $pro_mysql_product_table,
@@ -33,6 +27,7 @@ function productManager(){
 				),
 			"period" => array(
 				"type" => "text",
+				"help" => _("Period for the product with format YYYY-MM-DD. For example, if you want a product that will last 1 year, 2 months, and 3 days, write 0001-02-03. "),
 				"legend" => _("Period") ,
 				"size" => "10"
 				),
@@ -41,13 +36,20 @@ function productManager(){
 				"legend" => _("Price") ,
 				"size" => "4"
 				),
+			"setup_fee" => array(
+				"type" => "text",
+				"legend" => _("Setup fee") ,
+				"size" => "4"
+				),
 			"affiliate_kickback" => array(
 				"type" => "text",
-				"legend" => _("Aff. kickback") ,
+				"help" => _("This is the amount of money that you will give back to the affiliate account that made the sell possible."),
+				"legend" => _("Commission"). " " . $secpayconf_currency_symbol,
 				"size" => "4"
 				),
 			"quota_disk" => array(
 				"type" => "text",
+				"help" => _("Hard drive space in MBytes."),
 				"legend" => _("Disk") ,
 				"size" => "4"
 				),
@@ -69,11 +71,13 @@ function productManager(){
 			"allow_add_domain" => array(
 				"type" => "popup",
 				"legend" => _("Add domain") ,
+				"help" => _("If set to yes, the the admin can add a domain, if set to check, then it will go through moderation, set to no, no domain addition to account is possible by the admin."),
 				"values" => array("check","no","yes")
 				),
 			"private" => array(
 				"type" => "checkbox",
 				"legend" => _("Private") ,
+				"help" => _("If the private flag is set, then this product wont appear in the registration form."),
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No")),
 				"default" => "no")
@@ -81,6 +85,24 @@ function productManager(){
         	);
 	$out = dtcDatagrid($dsc);
 
+	// Build the product ID popup
+        $qp = "SELECT id,name FROM $pro_mysql_product_table WHERE renew_prod_id='0' AND heb_type='vps'";
+        $rp = mysql_query($qp)or die("Cannot query \"$qp\" !!! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+        $np = mysql_num_rows($rp);
+        $renew_id_popup = array();
+        $renew_id_popup[] = 0;
+        $renew_id_replace = array();
+        $renew_id_replace[] = _("Not a renewal product");
+	for($j=0;$j<$np;$j++){
+		$ap = mysql_fetch_array($rp);
+		$renew_id_popup[] = $ap["id"];
+		if(strlen($ap["name"]) > 20){
+			$renew_id_replace[] = $ap["id"]. ": " .substr($ap["name"],0,17)."...";
+		}else{
+			$renew_id_replace[] = $ap["id"]. ": " .$ap["name"];
+		}
+	}
+
         $dsc = array(
         	"table_name" => $pro_mysql_product_table,
         	"title" => _("Product list editor") ." (VPS)",
@@ -95,9 +117,10 @@ function productManager(){
 				),
 			"renew_prod_id" => array(
 				"type" => "popup",
+				"help" => _("If you set the renewal ID, then this entry will be considered as a renewal product for the matching ID."),
 				"legend" => _("Renewal-ID") ,
 				"values" => $renew_id_popup,
-				"display_replace" => array("No-renew")
+				"display_replace" => $renew_id_replace
 				),
 			"name" => array(
 				"type" => "text",
@@ -106,6 +129,7 @@ function productManager(){
 				),
 			"period" => array(
 				"type" => "text",
+				"help" => _("Period for the product with format YYYY-MM-DD. For example, if you want a product that will last 1 year, 2 months, and 3 days, write 0001-02-03. "),
 				"legend" => _("Period") ,
 				"size" => "10"
 				),
@@ -114,29 +138,39 @@ function productManager(){
 				"legend" => _("Price") ,
 				"size" => "4"
 				),
+			"setup_fee" => array(
+				"type" => "text",
+				"legend" => _("Setup fee") ,
+				"size" => "4"
+				),
 			"affiliate_kickback" => array(
 				"type" => "text",
-				"legend" => _("Aff. kickback") ,
+				"help" => _("This is the amount of money that you will give back to the affiliate account that made the sell possible."),
+				"legend" => _("Commission"). " " . $secpayconf_currency_symbol,
 				"size" => "4"
 				),
 			"quota_disk" => array(
 				"type" => "text",
+				"help" => _("Hard drive space in MBytes."),
 				"legend" => _("Disk") ,
 				"size" => "4"
 				),
 			"memory_size" => array(
 				"type" => "text",
+				"help" => _("Memory size in MBytes."),
 				"legend" => _("RAM") ,
 				"size" => "4"
 				),
 			"bandwidth" => array(
 				"type" => "text",
+				"help" => _("Bandwidth per month in MBytes."),
 				"legend" => _("Traffic") ,
 				"size" => "5"
 				),
 			"private" => array(
 				"type" => "checkbox",
 				"legend" => _("Private") ,
+				"help" => _("If the private flag is set, then this product wont appear in the registration form."),
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No")),
 				"default" => "no")
@@ -144,6 +178,24 @@ function productManager(){
         	);
 	$out .= dtcDatagrid($dsc);
 
+	// Build the product ID popup
+        $qp = "SELECT id,name FROM $pro_mysql_product_table WHERE renew_prod_id='0' AND heb_type='server'";
+        $rp = mysql_query($qp)or die("Cannot query \"$qp\" !!! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+        $np = mysql_num_rows($rp);
+        $renew_id_popup = array();
+        $renew_id_popup[] = 0;
+        $renew_id_replace = array();
+        $renew_id_replace[] = _("Not a renewal product");
+	for($j=0;$j<$np;$j++){
+		$ap = mysql_fetch_array($rp);
+		$renew_id_popup[] = $ap["id"];
+		if(strlen($ap["name"]) > 20){
+			$renew_id_replace[] = $ap["id"]. ": " .substr($ap["name"],0,17)."...";
+		}else{
+			$renew_id_replace[] = $ap["id"]. ": " .$ap["name"];
+		}
+	}
+
         $dsc = array(
         	"table_name" => $pro_mysql_product_table,
         	"title" => _("Product list editor") ." (Dedicated servers)",
@@ -158,9 +210,10 @@ function productManager(){
 				),
 			"renew_prod_id" => array(
 				"type" => "popup",
+				"help" => _("If you set the renewal ID, then this entry will be considered as a renewal product for the matching ID."),
 				"legend" => _("Renewal-ID") ,
 				"values" => $renew_id_popup,
-				"display_replace" => array("No-renew")
+				"display_replace" => $renew_id_replace
 				),
 			"name" => array(
 				"type" => "text",
@@ -169,6 +222,7 @@ function productManager(){
 				),
 			"period" => array(
 				"type" => "text",
+				"help" => _("Period for the product with format YYYY-MM-DD. For example, if you want a product that will last 1 year, 2 months, and 3 days, write 0001-02-03. "),
 				"legend" => _("Period") ,
 				"size" => "10"
 				),
@@ -177,29 +231,39 @@ function productManager(){
 				"legend" => _("Price") ,
 				"size" => "4"
 				),
+			"setup_fee" => array(
+				"type" => "text",
+				"legend" => _("Setup fee") ,
+				"size" => "4"
+				),
 			"affiliate_kickback" => array(
 				"type" => "text",
-				"legend" => _("Aff. kickback") ,
+				"help" => _("This is the amount of money that you will give back to the affiliate account that made the sell possible."),
+				"legend" => _("Commission"). " " . $secpayconf_currency_symbol,
 				"size" => "4"
 				),
 			"quota_disk" => array(
 				"type" => "text",
+				"help" => _("Hard drive space in MBytes."),
 				"legend" => _("Disk") ,
 				"size" => "4"
 				),
 			"memory_size" => array(
 				"type" => "text",
+				"help" => _("Memory size in MBytes."),
 				"legend" => "RAM",
 				"size" => "4"
 				),
 			"bandwidth" => array(
 				"type" => "text",
+				"help" => _("Bandwidth per month in GBytes."),
 				"legend" => _("Traffic") ,
 				"size" => "5"
 				),
 			"private" => array(
 				"type" => "checkbox",
 				"legend" => _("Private") ,
+				"help" => _("If the private flag is set, then this product wont appear in the registration form."),
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No")),
 				"default" => "no")
@@ -222,6 +286,7 @@ function productManager(){
 			"renew_prod_id" => array(
 				"type" => "popup",
 				"legend" => _("Renewal-ID") ,
+				"help" => _("There must be ONLY ONE SSL product at any time, with only ONE renewal product."),
 				"values" => $renew_id_popup,
 				"display_replace" => array("No-renew")
 				),
@@ -232,6 +297,7 @@ function productManager(){
 				),
 			"period" => array(
 				"type" => "text",
+				"help" => _("Period for the product with format YYYY-MM-DD. For example, if you want a product that will last 1 year, 2 months, and 3 days, write 0001-02-03. "),
 				"legend" => _("Period") ,
 				"size" => "10"
 				),
@@ -240,14 +306,21 @@ function productManager(){
 				"legend" => _("Price") ,
 				"size" => "4"
 				),
+			"setup_fee" => array(
+				"type" => "text",
+				"legend" => _("Setup fee") ,
+				"size" => "4"
+				),
 			"affiliate_kickback" => array(
 				"type" => "text",
-				"legend" => _("Aff. kickback") ,
+				"help" => _("This is the amount of money that you will give back to the affiliate account that made the sell possible."),
+				"legend" => _("Commission"). " " . $secpayconf_currency_symbol,
 				"size" => "4"
 				),
 			"private" => array(
 				"type" => "checkbox",
 				"legend" => _("Private") ,
+				"help" => _("If the private flag is set, then this product wont appear in the registration form."),
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No")),
 				"default" => "no")
