@@ -51,6 +51,9 @@ function mail_account_generate_postfix(){
 	global $conf_use_cyrus;
 	global $conf_use_mail_alias_group;
 
+	global $conf_support_ticket_email;
+	global $conf_main_domain;
+
 	//global $conf_postfix_virtual_mailbox_domains_path;
 	//global $conf_postfix_virtual_path;
 	//global $conf_postfix_vmailbox_path;
@@ -157,7 +160,7 @@ function mail_account_generate_postfix(){
 //Mail Group Aliases Start
 			if ( $conf_use_mail_alias_group == "yes" )
 			{
-				if ( $domain["domain_parking"] != "no-parking" )
+				if ( $primary_mx && $domain["domain_parking"] != "no-parking" )
 				{
 					// @domain1 -> @domain2
 					$domains_postmasters_file.= "# Mail Alias Groups for ".$domain["name"]."\n";
@@ -221,11 +224,14 @@ function mail_account_generate_postfix(){
 					if ( $k==0 ) $domains_postmasters_file.= "# Mailboxes for : ".$domain_full_name."\n";
 					$spam_stuff_done = 0;
 					$homedir_created = 0;
-					if (!isset($home) || $home==""){
+					if (!isset($home) || $home=="" && $conf_use_cyrus != "yes"){
 						$console .= "Missing home variable for $id";
 					}
-					if(! is_dir($home) ){
+					if(! is_dir($home) && ($conf_use_cyrus != "yes")){
+						$PATH = getenv('PATH');
+						putenv("PATH=/usr/lib/courier-imap/bin:$PATH");
 						system("/bin/mkdir -p $home && maildirmake $home");
+						putenv("PATH=$PATH");
 						$homedir_created = 1;
 					}
 
@@ -416,6 +422,10 @@ function mail_account_generate_postfix(){
 		}
 	}
 
+	// Add the support@ email
+	$aliases_file .= "dtc_support_ticket_messages: \"|/usr/share/dtc/admin/support-receive.php\"\n";
+	$domains_postmasters_file .= $conf_support_ticket_email."@".$conf_main_domain." dtc_support_ticket_messages\n";
+
 	//write out our config files
 	$fp = fopen ( "$conf_postfix_virtual_mailbox_domains_path", "w");
 	fwrite($fp, $domains_file);
