@@ -61,5 +61,7 @@ require("genfiles/gen_named_files.php");
 require("genfiles/gen_backup_script.php");
 require("genfiles/gen_webalizer_stat.php");
 require("genfiles/gen_ssh_account.php");
+require("genfiles/gen_nagios.php");
+require("genfiles/gen_fetchmail.php");
 
 ?>
