@@ -1,9 +1,4 @@
 <?php
-/**
- * @package DTC
- * @version $id:$
- * @return new admin menu
- */
 
 function calculateAge($date,$time){
 	$exp_date = explode("-",$date);
@@ -23,78 +18,106 @@ function numOfDays($date,$time="00:00:00"){
 	return $age;
 }
 
-function mailUserTicketReply($adm_login,$subject,$body,$closed="no"){
+function mailUserTicketReply($adm_email,$hash,$subject,$body,$closed="no",$adm_login=""){
 	global $pro_mysql_admin_table;
 	global $pro_mysql_client_table;
+	global $pro_mysql_tik_admins_table;
 	global $conf_webmaster_email_addr;
 	global $conf_administrative_site;
 
 	global $conf_message_subject_header;
 	global $conf_main_domain;
 
-	$q = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login';";
-	$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
-	$n = mysql_num_rows($r);
-	if($n != 1){
-		return "Admin not found!";
-	}
-	$a = mysql_fetch_array($r);
-	$q = "SELECT * FROM $pro_mysql_client_table WHERE id='".$a["id_client"]."';";
-	$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
-	$n = mysql_num_rows($r);
-	if($n != 1){
-		return "Admin not found!";
-	}
-	$a = mysql_fetch_array($r);
-	$headers = "From: NO-REPLY-USE-DTC <no-reply@$conf_main_domain>";
+	global $conf_support_ticket_email;
+	global $conf_support_ticket_domain;
+	global $conf_recipient_delimiter;
+	global $conf_main_domain;
 
+	global $send_email_header;
+	global $pro_mysql_tik_admins_table;
+
+	if($conf_support_ticket_domain == "default"){
+		$support_domain = $conf_main_domain;
+	}
+
+	$support_email = $conf_support_ticket_email.$conf_recipient_delimiter.$hash."@".$support_domain;
+	$headers = $send_email_header;
+	$headers .= "From: $conf_support_ticket_email@$support_domain <$support_email>";
+	$header_admin_reply = readCustomizedMessage("tickets/header_admin_reply",$adm_login);
 	$content = "Subject: ".stripslashes($subject)."
 
+$header_admin_reply
+**********
+$body
+**********
+";
+
+	if($closed == "no"){
+		$text_filename = "tickets/footer_admin_reply_no_close";
+	}else{
+		$text_filename = "tickets/footer_admin_reply_close";
+	}
+	$footer_admin_reply = readCustomizedMessage($text_filename,$adm_login);
+	$footer_admin_reply = str_replace("%%%DTC_CLIENT_URL%%%","http://$conf_administrative_site/dtc/",$footer_admin_reply);
+	$footer_admin_reply = str_replace("%%%SUPPORT_EMAIL_ADDRESS%%%",$support_email,$footer_admin_reply);
+
+	$content .= $footer_admin_reply;
+
+	$tocustomer_subject = readCustomizedMessage("tickets/subject_admin_reply",$adm_login);
+
+	$q = "SELECT * FROM $pro_mysql_tik_admins_table WHERE pseudo='".$_SERVER["PHP_AUTH_USER"]."';";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n != 1){
+		die("Ticket admin not found line ".__LINE__." file ".__FILE__);
+	}
+	$a = mysql_fetch_array($r);
+	$realname = $a["realname"];
+	mail($adm_email,$conf_message_subject_header." ".$realname." ".$tocustomer_subject,$content,$headers);
+
+	// Mail the ticket reply to all administrators
+	$adm_content = "Subject: ".stripslashes($subject)."
+
 Hello,
 
-An administrator has replied to your support ticket.
-Below is a copy of the reply sent by the administrator.
+An administrator has replied to a support ticket. Below is a copy of
+his reply to the customer:
 
 **********
 $body
 **********
 
-Please DO NOT reply to this mail. In order to keep a history,
-reply faster, and enable us to share the support work with
-all the members of our team, use the control panel support
-ticket tab to reply.
+The administrator decided that the issue is:
 
 ";
-
-	if($closed == "yes"){
-		$content .= "Note that the ticket is still open, meaning we are waiting
-for your answer. So please login to the control panel at the
-following URL:
-
-http://$conf_administrative_site/dtc/
-
-with your login $adm_login, then go in the support ticket tab
-and type your reply.
-";
+	if($closed == "no"){
+		$adm_content .= "OPEN TO FURTHER DISCUSSION\n";
 	}else{
-		$content .= "Note that the ticket has been closed, meaning that there is
-no need for another reply. If you are still needing help, then
-you must open a new support ticket. To do so, login to the
-control panel at the following URL:
+		$adm_content .= "CLOSED\n";
+	}
 
-http://$conf_administrative_site/dtc/
+	// Use email if login is empty (case of an admin email not in the DB)
+	if ( $adm_login == "" ){
+		$subject_line_adm_name = $adm_email;
+	}else{
+		$subject_line_adm_name = $adm_login;
+	}
 
-with your login $adm_login, then go in the support
-ticket tab and type your reply.
-";
+	$q = "SELECT * FROM $pro_mysql_tik_admins_table WHERE available='yes';";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+	$n = mysql_num_rows($r);
+	for($i=0;$i<$n;$i++){
+		$a = mysql_fetch_array($r);
+		mail($a["email"],"$conf_message_subject_header ".$_SERVER["PHP_AUTH_USER"]." replied to the support ticket of ".$subject_line_adm_name,$adm_content,$headers);
 	}
-	mail($a["email"],"$conf_message_subject_header An administrator replied to your support ticket",$content,$headers);
 }
 
 function drawNewAdminForm(){
 	global $conf_site_root_host_path;
 	global $lang;
 
+	global $pro_mysql_admin_table;
+	global $pro_mysql_client_table;
 	global $pro_mysql_new_admin_table;
 	global $pro_mysql_pending_queries_table;
 	global $pro_mysql_pay_table;
@@ -107,6 +130,7 @@ function drawNewAdminForm(){
 	global $pro_mysql_dedicated_table;
 
 	global $secpayconf_currency_letters;
+	global $secpayconf_use_maxmind;
 
 	get_secpay_conf();
 
@@ -120,7 +144,7 @@ function drawNewAdminForm(){
 			return _("Cannot find ticket!");
 		}
 		$a = mysql_fetch_array($r);
-		$out .= _("Subject: ") .stripslashes($a["subject"])."<br>";
+		$out .= _("Subject: ") .htmlspecialchars(stripslashes($a["subject"]))."<br>";
 
 		$q2 = "SELECT * FROM $pro_mysql_tik_cats_table WHERE id='".$a["cat_id"]."';";
 		$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
@@ -155,7 +179,12 @@ function drawNewAdminForm(){
 			}else{
 				$bg = " bgcolor=\"#FFFFAA\" ";
 			}
-			$out .= "<tr><td$bg valign=\"top\"><i>".$a["date"]." ".$a["time"]."</i></td><td$bg>".nl2br(stripslashes($a["text"]))."</td></tr>";
+			if($a["admin_or_user"] == "admin"){
+                        	$replied_by = "<br>"._("Replied by:")." ".$a["admin_name"];
+			}else{
+				$replied_by = "";
+			}
+			$out .= "<tr><td$bg valign=\"top\"><i>".$a["date"]." ".$a["time"]."</i>".$replied_by."</td><td$bg>".nl2br(htmlspecialchars(stripslashes($a["text"])))."</td></tr>";
 			if($a["request_close"] == "yes"){
 				$close_request = "yes";
 			}
@@ -167,10 +196,11 @@ function drawNewAdminForm(){
 		}else{
 			$out .= "<font color=\"#FF0000\">"._("No")."</font><br>";
 		}
-		$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
+		$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\" method=\"post\">
 		<input type=\"hidden\" name=\"subaction\" value=\"ticket_reply\">
 		<textarea cols=\"100\" rows=\"10\" wrap=\"physical\" name=\"ticketbody\"></textarea><br>
 		<input type=\"hidden\" name=\"tik_id\" value=\"".$_REQUEST["tik_id"]."\">
+		<input type=\"hidden\" name=\"server_hostname\" value=\"".$a["server_hostname"]."\">
 		<input type=\"hidden\" name=\"last_tik_id\" value=\"$last_tik\">
 		<div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\" onMouseOut=\"this.className='input_btn_container';\">
  <div class=\"input_btn_left\"></div>
@@ -204,20 +234,60 @@ function drawNewAdminForm(){
 		}else{
 			$closed = "yes";
 		}
+		$adm_login = $a["adm_login"];
+		if( strlen($adm_login) != 0){
+			$q = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login';";
+			$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
+			$n = mysql_num_rows($r);
+			if($n != 1){
+				return "Admin not found!";
+			}
+			$admin = mysql_fetch_array($r);
+			$q = "SELECT * FROM $pro_mysql_client_table WHERE id='".$admin["id_client"]."';";
+			$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
+			$n = mysql_num_rows($r);
+			if($n != 1){
+				return "Admin not found!";
+			}
+			$client = mysql_fetch_array($r);
+		}else{
+			$adm_login = "";
+		}
 		if(isset($_REQUEST["answer"]) || isset($_REQUEST["answer_close"])){
-			$q2 = "INSERT INTO $pro_mysql_tik_queries_table (id,adm_login,date,time,in_reply_of_id,reply_id,admin_or_user,subject,text,cat_id,initial_ticket,server_hostname,closed)
-			VALUES ('','".$a["adm_login"]."','".date("Y-m-d")."','".date("H:i:s")."','".$_REQUEST["last_tik_id"]."','0','admin','".mysql_real_escape_string($a["subject"])."','".mysql_real_escape_string($_REQUEST["ticketbody"])."','".$a["cat_id"]."','".$a["id"]."','".$a["server_hostname"]."','$closed');";
+			$qps = "SELECT * FROM $pro_mysql_tik_admins_table WHERE pseudo='".$_SERVER["PHP_AUTH_USER"]."';";
+			$rps = mysql_query($qps)or die("Cannot query $qps line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$nps = mysql_num_rows($rps);
+			if($nps != 1){
+				die("Ticket admin not found line ".__LINE__." file ".__FILE__);
+			}
+			$aps = mysql_fetch_array($rps);
+			$pseudo = $aps["pseudo"];
+
+			$q2 = "INSERT INTO $pro_mysql_tik_queries_table (id,adm_login,date,time,in_reply_of_id,reply_id,admin_or_user,subject,text,cat_id,initial_ticket,server_hostname,closed,admin_name)
+			VALUES ('','".$a["adm_login"]."','".date("Y-m-d")."','".date("H:i:s")."','".$_REQUEST["last_tik_id"]."','0','admin','".mysql_real_escape_string($a["subject"])."','".mysql_real_escape_string($_REQUEST["ticketbody"])."','".$a["cat_id"]."','no','".$a["server_hostname"]."','$closed','$pseudo');";
 			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			$ins_id = mysql_insert_id();
 			$q2 = "UPDATE $pro_mysql_tik_queries_table SET reply_id='$ins_id' WHERE id='".$_REQUEST["last_tik_id"]."';";
 			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 			$out .= "Ticket reply sent!<br>";
-			mailUserTicketReply($a["adm_login"],$a["subject"],$_REQUEST["ticketbody"],$closed);
+			if( strlen($adm_login) != 0){
+				mailUserTicketReply($client["email"],$a["hash"],$a["subject"],$_REQUEST["ticketbody"],$closed,$adm_login);
+			}
+			if( strlen($a["customer_email"]) != 0){
+				mailUserTicketReply($a["customer_email"],$a["hash"],$a["subject"],$_REQUEST["ticketbody"],$closed,$adm_login);
+			}
 		}
 		if($closed == "yes"){
 			$q2 = "UPDATE $pro_mysql_tik_queries_table SET closed='yes' WHERE id='".$_REQUEST["tik_id"]."';";
 			$r2 = mysql_query($q2)or die("Cannot query $q2 line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
-			mailUserTicketReply($a["adm_login"],"The ticket has been closed (without text reply)","The ticket has been closed (without text reply)");
+		}
+		if( isset($_REQUEST["close"]) ){
+			if( strlen($adm_login) != 0){
+				mailUserTicketReply($client["email"],$a["hash"],"The ticket has been closed (without text reply)","The ticket has been closed (without text reply)",$closed,$adm_login);
+			}
+			if( strlen($a["customer_email"]) != 0){
+				mailUserTicketReply($a["customer_email"],$a["hash"],"The ticket has been closed (without text reply)","The ticket has been closed (without text reply)",$closed,$adm_login);
+			}
 		}
 	}
 
@@ -234,6 +304,11 @@ dtcFromOkDraw()."
 </table>
 ";
 
+	if($secpayconf_use_maxmind == "yes"){
+		$maxmindsays_th = "<td>" . _("MaxMind says") . "</td>";
+	}else{
+		$maxmindsays_th = "";
+	}
 	// Draw the list of users awaiting for an account
 	$waiting_new_users = "<h3>". _("User and domain waiting for addition:") ."</h3>";
 	$q = "SELECT * FROM $pro_mysql_new_admin_table ORDER BY date,time";
@@ -243,7 +318,7 @@ dtcFromOkDraw()."
 		$waiting_new_users .= "<b>". _("No user waiting!") ."</b>";
 	}else{
 		$waiting_new_users .= "<table width=\"100%\"border=\"1\">
-<tr><td>". _("Name") ."</td><td>". _("Login") ."</td><td>". _("Domain name / VPS server hostname") ."</td><td>". _("Product") ."</td><td>". _("Date") . "</td><td>". _("Bank validated") ."</td><td>MaxMind says</td><td>". _("Action") ."</td></tr>";
+<tr><td>". _("Name") ."</td><td>". _("Login") ."</td><td>". _("Domain name / VPS server hostname") ."</td><td>". _("Product") ."</td><td>". _("Date") . "</td><td>". _("Bank validated") ."</td>$maxmindsays_th<td>". _("Action") ."</td></tr>";
 		for($i=0;$i<$n;$i++){
 			$a = mysql_fetch_array($r);
 			$waiting_new_users .= "<tr><td style=\"white-space:nowrap\"><u>".$a["comp_name"].":</u><br>";
@@ -278,16 +353,18 @@ dtcFromOkDraw()."
 				if($a2["valid"] == "yes"){
 					$waiting_new_users .= "<td><font color=\"green\">"._("Yes")."</font></td>";
 				}elseif($a2["valid"] == "pending"){
-					$waiting_new_users .= "<td><font color=\"#FF8800\">". _("Pending") ."</font></td>";
+					$waiting_new_users .= "<td><font color=\"#FF8800\">". _("Pending") .": ". $a2["pending_reason"] ."</font></td>";
 				}else{
 					$waiting_new_users .= "<td><font color=\"red\">"._("No")."</font></td>";
 				}
 			}
-			$waiting_new_users .= "<td><pre style='width: 200px; height: 100px; overflow: scroll;'>".htmlspecialchars(
-				print_r(unserialize($a["maxmind_output"]),true))."</pre></td>";
-			$waiting_new_users .= "<td style=\"white-space:nowrap\"><a target=\"_blank\" href=\"/dtcadmin/view_waitingusers.php?reqadm_login=".$a["reqadm_login"]."\">". _("View details") ."</a><br/>
-			<a href=\"".$_SERVER["PHP_SELF"]."?action=valid_waiting_user&reqadm_login=".$a["reqadm_login"]."\">". _("Add") ."</a><br/>
-			<a href=\"".$_SERVER["PHP_SELF"]."?action=delete_waiting_user&reqadm_login=".$a["reqadm_login"]."\">". _("Delete") ."</a></td>";
+			if($secpayconf_use_maxmind == "yes"){
+				$waiting_new_users .= "<td><pre style='width: 200px; height: 100px; overflow: scroll;'>".htmlspecialchars(
+					print_r(unserialize($a["maxmind_output"]),true))."</pre></td>";
+			}
+			$waiting_new_users .= "<td style=\"white-space:nowrap\"><a target=\"_blank\" href=\"/dtcadmin/view_waitingusers.php?reqadm_id=".$a["id"]."\">". _("View details") ."</a><br/>
+			<a href=\"".$_SERVER["PHP_SELF"]."?action=valid_waiting_user&reqadm_id=".$a["id"]."\">". _("Add") ."</a><br/>
+			<a href=\"".$_SERVER["PHP_SELF"]."?action=delete_waiting_user&reqadm_id=".$a["id"]."\">". _("Delete") ."</a></td>";
 			$waiting_new_users .= "</tr>";
 		}
 		$waiting_new_users .= "</table>";
@@ -398,7 +475,7 @@ dtcFromOkDraw()."
 		}
 		$waiting_new_users .= "</table>";
 	}
-	// Ticket manager
+	// Ticket manager: draw all open tickets
 	$q = "SELECT * FROM $pro_mysql_tik_queries_table WHERE closed='no' AND initial_ticket='yes' ORDER BY `date`,`time`;";
 	$r = mysql_query($q)or die("Cannot query \"$q\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 	$n = mysql_num_rows($r);
@@ -409,7 +486,15 @@ dtcFromOkDraw()."
 <tr><td>". _("Login") ."</td><td>". _("Age") ."</td><td>". _("Type") ."</td><td>". _("Subject") ."</td><td>". _("Last message from"). "</td><td>" ._("Last message age"). "</td></tr>";
 		for($i=0;$i<$n;$i++){
 			$a = mysql_fetch_array($r);
-			$waiting_new_users .= "<tr><td>".$a["adm_login"]."</td>";
+			if( strlen($a["customer_email"]) != 0){
+				$who = $a["customer_email"];
+				if( strlen($a["adm_login"]) != 0){
+					$who .= " / ".$a["adm_login"];
+				}
+			}else{
+				$who = $a["adm_login"];
+			}
+			$waiting_new_users .= "<tr><td>$who</td>";
 			$q2 = "SELECT * FROM $pro_mysql_tik_cats_table WHERE id='".$a["cat_id"]."'";
 			$r2 = mysql_query($q2)or die("Cannot query \"$q2\" ! Line: ".__LINE__." in file: ".__FILE__." mysql said: ".mysql_error());
 			$n2 = mysql_num_rows($r2);
@@ -420,7 +505,7 @@ dtcFromOkDraw()."
 				$cat = $a2["catname"];
 			}
 			$age = calculateAge($a["date"],$a["time"]);
-			$waiting_new_users .= "<td style=\"white-space:nowrap;\">$age</td><td>$cat</td><td style=\"white-space:nowrap;\"><a href=\"".$_SERVER["PHP_SELF"]."?subaction=resolv_ticket&tik_id=".$a["id"]."\">".stripslashes($a["subject"])."</a></td>";
+			$waiting_new_users .= "<td style=\"white-space:nowrap;\">$age</td><td>$cat</td><td style=\"white-space:nowrap;\"><a href=\"".$_SERVER["PHP_SELF"]."?subaction=resolv_ticket&tik_id=".$a["id"]."\">".htmlspecialchars(stripslashes($a["subject"]))."</a></td>";
 			$next_reply_id = $a["reply_id"];
 			$last_reply_text = "<font color=\"green\">". _("Admin"). "</font>";
 			$last_message_date = $a["date"];
