@@ -28,6 +28,9 @@ function drawDTCConfigMenu(){
 		"general" => array(
 			"text" => gettext("General"),
 			"icon" => "box_wnb_nb_picto-general.gif"),
+		"ticket" => array(
+			"text" => gettext("Support and auth"),
+			"icon" => "box_wnb_nb_picto-supportickets.gif"),
 		"ip" => array(
 			"text" => gettext("IP addresses and network"),
 			"icon" => "box_wnb_nb_picto-ipaddresses.gif"),
@@ -37,8 +40,11 @@ function drawDTCConfigMenu(){
 		"ip_pool" => array(
 			"text" => gettext("IP addresses pool"),
 			"icon" => "box_wnb_nb_picto-sslip.gif"),
+		"nagios" => array(
+			"text" => _("Nagios host"),
+			"icon" => "box_wnb_nb_picto-sslip.gif"),
 		"dedicatedip" => array(
-			"text" => _("Dedicated server IP addresses"),
+			"text" => _("Dedicated server IPs"),
 			"icon" => "box_wnb_nb_picto-dedicatedservers.gif"),
 		"zonefile" => array(
 			"text" => gettext("Named zonefiles"),
@@ -49,9 +55,6 @@ function drawDTCConfigMenu(){
 		"ftpbackup" => array(
 			"text" => gettext("FTP backup"),
 			"icon" => "box_wnb_nb_picto-ftpbackup.gif"),
-		"ticket" => array(
-			"text" => gettext("Support ticket"),
-			"icon" => "box_wnb_nb_picto-supportickets.gif"),
 		"vps" => array(
 			"text" => gettext("VPS servers"),
 			"icon" => "box_wnb_nb_picto-vpsservers.gif"),
@@ -181,6 +184,19 @@ function configEditorTemplate ($dsc,$conftype="config"){
 			}
 			$control = "<select class=\"$input_class\" name=\"".$keys[$i]."\">".$control."</select>";
 			break;
+		case "textarea":
+			if( isset($dsc["cols"][ $keys[$i] ]["cols"]) ){
+				$cols = " cols=\"".$dsc["cols"][ $keys[$i] ]["cols"]."\" ";
+			}else{
+				$cols = "";
+			}
+			if( isset($dsc["cols"][ $keys[$i] ]["rows"]) ){
+				$rows = " rows=\"".$dsc["cols"][ $keys[$i] ]["rows"]."\" ";
+			}else{
+				$rows = "";
+			}
+			$control = "<textarea class=\"$input_class\" $cols $rows name=\"".$keys[$i]."\">".$$fld."</textarea>";
+			break;
 		case "text":
 		default:
 			if( isset($dsc["cols"][ $keys[$i] ]["size"]) ){
@@ -236,9 +252,43 @@ are stored in /etc/dtc, and if not present in: ").$conf_dtcadmin_path."/reminder
 	return configEditorTemplate ($dsc);
 }
 
+function drawNagiosConfig(){
+
+	global $conf_dtcadmin_path;
+	$out = "";
+
+	$dsc = array(
+		"title" => _("Nagios monitoring"),
+		"action" => "vps_renewal_period",
+		"forward" => array("rub","sousrub"),
+		"desc" => _("DTC lets you auto-configure a Nagios monitoring server, enabling your VPS customers know when their services are working. This works by generating the Nagios configuration file and copying it using SCP to the remote Nagios server, then using SSH to restart the remote Nagios service.<br><br>
+Unfortunately, this requires some manual intervention to set up SSH keys: you must manually add a user to your Nagios server, and give it sudo access to restart the Nagios service. Then you must set up public key authentication for that user, add the Nagios server's SSH public key to the DTC user's SSH keyring, and create an empty config file which must be writable by the user in the Nagios server."),
+		"cols" => array(
+			"nagios_host" => array(
+				"legend" => _("Nagios host name: "),
+				"type" => "text",
+				"size" => "16"),
+			"nagios_username" => array(
+				"legend" => _("User name on the Nagios machine: "),
+                                "type" => "text",
+                                "size" => "16"),
+			"nagios_config_file_path" => array(
+				"legend" => _("Path to the Nagios configuration file to be created: "),
+                                "type" => "text",
+                                "size" => "16"),
+			"nagios_restart_command" => array(
+				"legend" => _("Command line that, run in the Nagios server, will reload its configuration: "),
+                                "type" => "text",
+                                "size" => "16")
+			)
+		);
+	return configEditorTemplate ($dsc);
+}
+
 function drawDedicatedIPConfig(){
 	global $pro_mysql_dedicated_ips_table;
 	global $pro_mysql_dedicated_table;
+	global $pro_mysql_ip_pool_table;
 	$out = "";
 
 	$q = "SELECT server_hostname FROM $pro_mysql_dedicated_table ORDER BY server_hostname";
@@ -250,10 +300,30 @@ function drawDedicatedIPConfig(){
 		$popup_vals[] = $a["server_hostname"];
 	}
 
+	$q = "SELECT * FROM $pro_mysql_ip_pool_table";
+	$r = mysql_query($q) or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n == 0){
+		$out .= "<font color=\"red\">". _("Warning: no IP pool in the database!") ."</font>";
+	}
+	unset($my_pool_values);
+	unset($my_pool_text);
+	$my_pool_values = array();
+	$my_pool_text = array();
+	$my_pool_values[] = 0;
+	$my_pool_text[] = "Not set";
+	for($i=0;$i<$n;$i++){
+		$a = mysql_fetch_array($r);
+		$my_pool_values[] = $a["id"];
+		$my_pool_text[] = $a["location"] . " " . $a["ip_addr"] . " " . $a["netmask"];
+	}
+
+
 	$dsc = array(
 		"table_name" => $pro_mysql_dedicated_ips_table,
 		"title" => _("Dedicated server IP address pool editor"),
 		"action" => "dedicated_ip_list",
+		"order_by" => "dedicated_server_hostname,ip_addr",
 		"forward" => array("rub","sousrub"),
 		"update_check_callback" => "checkIPAssigned",
 		"insert_check_callback" => "checkIPAssigned",
@@ -265,6 +335,11 @@ function drawDedicatedIPConfig(){
 			"ip_addr" => array(
 				"type" => "text",
 				"legend" => _("IPs addrs")),
+			"ip_pool_id" => array(
+				"type" => "popup",
+				"legend" => _("IP Pool"),
+				"values" => $my_pool_values,
+				"display_replace" => $my_pool_text),
 			"dedicated_server_hostname" => array(
 				"type" => "popup",
 				"values" => $popup_vals,
@@ -277,6 +352,10 @@ function drawDedicatedIPConfig(){
 
 function drawIPPoolConfig(){
 	global $pro_mysql_ip_pool_table;
+	global $pro_mysql_dedicated_ips_table;
+	global $pro_mysql_vps_ip_table;
+	global $pro_mysql_cronjob_table;
+
 	global $rub;
 	global $sousrub;
 
@@ -291,15 +370,32 @@ function drawIPPoolConfig(){
 				"type" => "id",
 				"display" => "no",
 				"legend" => "id"),
+			"editpool" => array(
+				"type" => "hyperlink",
+				"legend" => _("Customize"),
+				"text" => _("Customize") ),
 			"location" => array(
 				"type" => "text",
 				"legend" => _("Location")),
 			"ip_addr" => array(
 				"type" => "text",
-				"legend" => _("IPs addrs")),
+				"legend" => _("Network")),
 			"netmask" => array(
 				"type" => "text",
+				"size" => "12",
 				"legend" => _("Netmask")),
+			"broadcast" => array(
+				"type" => "text",
+				"size" => "12",
+				"legend" => _("Broadcast")),
+			"gateway" => array(
+				"type" => "text",
+				"size" => "12",
+				"legend" => _("Gateway")),
+			"dns" => array(
+				"type" => "text",
+				"size" => "12",
+				"legend" => _("DNS")),
 			"zone_type" => array(
 				"type" => "popup",
 				"legend" => _("Type of zone generation"),
@@ -308,6 +404,41 @@ function drawIPPoolConfig(){
 			)
 		);
 	$out .= dtcDatagrid($dsc);
+	$out .= "<br><br>";
+
+	if(isset($_REQUEST["editpool"])){
+		if(isset($_REQUEST["action"]) && $_REQUEST["action"] = "edit_custom_rdns_text"){
+			$q = "UPDATE $pro_mysql_ip_pool_table SET custom_part='".$_REQUEST["custom_part"]."' WHERE id='".$_REQUEST["editpool"]."';";
+			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__file__." sql said: ".mysql_error());
+			$q = "UPDATE $pro_mysql_dedicated_ips_table SET rdns_regen='yes' WHERE ip_pool_id='".$_REQUEST["editpool"]."';";
+			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__file__." sql said: ".mysql_error());
+			$q = "UPDATE $pro_mysql_vps_ip_table SET rdns_regen='yes' WHERE ip_pool_id='".$_REQUEST["editpool"]."';";
+			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__file__." sql said: ".mysql_error());
+			$q = "UPDATE $pro_mysql_cronjob_table SET reload_named='yes',gen_named='yes' WHERE 1;";
+			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__file__." sql said: ".mysql_error());
+		}
+		$q = "SELECT * FROM $pro_mysql_ip_pool_table WHERE id='".$_REQUEST["editpool"]."';";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__file__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			$out .= "<font color=\"red\">"._("Error: no IP pool by that ID!")."</font>";
+		}else{
+			$a = mysql_fetch_array($r);
+			$out .= "<h3>"._("Custom RDNS entries for the IP pool")." " .$a["location"] . " (" . $a["ip_addr"] . " / " . $a["netmask"] . "):</h3>";
+			$out .= _("The following will be appened at the end of the reverse zone file.");
+			$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
+<input type=\"hidden\" name=\"rub\" value=\"$rub\">
+<input type=\"hidden\" name=\"sousrub\" value=\"".$_REQUEST["sousrub"]."\">
+<input type=\"hidden\" name=\"editpool\" value=\"".$_REQUEST["editpool"]."\">
+<input type=\"hidden\" name=\"action\" value=\"edit_custom_rdns_text\">
+<textarea name=\"custom_part\" cols=\"80\" rows=\"20\">".$a["custom_part"]."</textarea><br>
+<div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\" onMouseOut=\"this.className='input_btn_container';\">
+<div class=\"input_btn_left\"></div>
+<div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" value=\""._("Save")."\"></div>
+<div class=\"input_btn_right\"></div></div></form>
+";
+		}
+	}
 	return $out;
 }
 
@@ -357,10 +488,145 @@ function drawSSLIPConfig(){
 function drawTicketConfig(){
 	global $pro_mysql_tik_admins_table;
 	global $pro_mysql_tik_cats_table;
+	global $pro_mysql_domain_table;
 	global $rub;
 	global $sousrub;
+	global $conf_all_customers_list_domain;
+	global $conf_all_customers_list_email;
+	global $pro_mysql_list_table;
+	global $pro_mysql_domain_table;
+	global $pro_mysql_client_table;
+
+	$out = "";
+
+	$domains = array();
+	$domains[] = "default";
+	$q = "SELECT name FROM $pro_mysql_domain_table;";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." mysql said ".mysql_error());
+	$n = mysql_num_rows($r);
+	for($i=0;$i<$n;$i++){
+		$a = mysql_fetch_array($r);
+		$domains[] = $a["name"];
+	}
+
+	$all_lists = array();
+	$domains[] = _("no list selected");
+	$q = "SELECT * FROM $pro_mysql_list_table WHERE domain='$conf_all_customers_list_domain';";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." mysql said ".mysql_error());
+	$n = mysql_num_rows($r);
+	for($i=0;$i<$n;$i++){
+		$a = mysql_fetch_array($r);
+		$all_lists[] = $a["name"];
+	}
+
+
+	$dsc = array(
+		"title" => _("Mailing list for sending email to all customers"),
+		"action" => "tik_global_param_list",
+		"forward" => array("rub","sousrub"),
+		"cols" => array(
+			"all_customers_list_email" => array(
+				"legend" => _("All customers list address: "),
+				"type" => "popup",
+				"values" => $all_lists
+				),
+			"all_customers_list_domain" => array(
+				"legend" => "@",
+				"type" => "popup",
+				"values" => $domains
+				)
+			)
+		);
+	$out .= configEditorTemplate ($dsc);
+
+	if( isset($_REQUEST["action"]) && $_REQUEST["action"] == "resubscript_all_users"){
+		$q = "SELECT owner FROM $pro_mysql_domain_table WHERE name='$conf_all_customers_list_domain';";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			die("No domain by this name: $conf_all_customers_list_domain line ".__LINE__." file ".__FILE__);
+		}
+		$a = mysql_fetch_array($r);
+		$admpath = getAdminPath($a["owner"]);
+		$subs_path = $admpath . "/$conf_all_customers_list_domain/lists/" . $conf_all_customers_list_domain . "_" . $conf_all_customers_list_email . "/subscribers.d";
+		if( !is_dir($subs_path)){
+			$out .= "<font color=\"red\">" . _("Could not find the folder"). " " . $subs_path . " " . _("when resubscribing all users.") . "</font>";
+		}else{
+			// First we list all files in the subscriber.d folder
+			$file_list = array();
+			if ($dh = opendir($subs_path)) {
+				while (($file = readdir($dh)) !== false) {
+					$fullpath = $subs_path . "/" . $file;
+					if(filetype($fullpath) != "dir"){
+						$file_list[] = $fullpath;
+					}
+				}
+			}
+			// Then we delete them all
+			$n = sizeof($file_list);
+			for($i=0;$i<$n;$i++){
+				unlink($file_list[$i]);
+			}
+			// Then we get a list of all the users and we subscribe them
+			$old_file = "";
+			$addr_list = "";
+			$q = "SELECT DISTINCT email FROM $pro_mysql_client_table ORDER BY email";
+			$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$n = mysql_num_rows($r);
+			for($i=0;$i<$n;$i++){
+				$a = mysql_fetch_array($r);
+				$fname = strtolower( substr($a["email"],0,1) );
+				if($fname == $old_file || $old_file == ""){
+					$addr_list .= $a["email"]."\n";
+				}else{
+					$fullpath = $subs_path."/".$old_file;
+					$fp = fopen($fullpath,"w+");
+					fwrite($fp,$addr_list);
+					fclose($fp);
+					$addr_list = $a["email"]."\n";
+				}
+				$old_file = $fname;
+			}
+			if($n > 0){
+				$fullpath = $subs_path."/".substr($a["email"],0,1);
+				$fp = fopen($fullpath,"w+");
+				fwrite($fp,$addr_list);
+				fclose($fp);
+			}
+		}
+	}
+	$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
+<input type=\"hidden\" name=\"rub\" value=\"$rub\">
+<input type=\"hidden\" name=\"sousrub\" value=\"".$_REQUEST["sousrub"]."\">
+<input type=\"hidden\" name=\"action\" value=\"resubscript_all_users\">
+<div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\" onMouseOut=\"this.className='input_btn_container';\">
+<div class=\"input_btn_left\"></div>
+<div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" value=\""._("Resubscribe all users")."\"></div>
+<div class=\"input_btn_right\"></div></div></form><br><br>
+"._("Note that you should always click on the above button to resubscribe all of your users before sending an email to the list")."<br>
+";
+
+
+	$out .= "<h3>"._("Support ticket configuration")."</h3>";
+
+	$dsc = array(
+		"title" => _("Ticket global parameters"),
+		"action" => "tik_global_param",
+		"forward" => array("rub","sousrub"),
+		"cols" => array(
+			"support_ticket_email" => array(
+				"legend" => _("Support ticket email address: "),
+				"type" => "text",
+				"size" => "32"),
+			"support_ticket_domain" => array(
+				"legend" => "@",
+				"type" => "popup",
+				"values" => $domains
+				)
+			)
+		);
+	$out .= configEditorTemplate ($dsc);
 
-	$out = "<h3>"._("Support ticket configuration")."</h3>";
 	$dsc = array(
 		"table_name" => $pro_mysql_tik_admins_table,
 		"title" => _("List of the administrators receiving request for support messages:"),
@@ -380,6 +646,9 @@ function drawTicketConfig(){
 			"email" => array(
 				"type" => "text",
 				"legend" => _("Email addr")),
+			"tikadm_pass" => array(
+				"type" => "password",
+				"legend" => _("Password")),
 			"available" => array(
 				"type" => "radio",
 				"legend" => _("Available"),
@@ -517,12 +786,14 @@ function checkIPAssigned(){
 		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__file__." sql said: ".mysql_error());
 		$n = mysql_num_rows($r);
 		if($n != 0){
+			$a = mysql_fetch_array($r);
 			$action_error_txt = _("The IP address $test_ip is already assigned to a VPS: cannot assign this one!");
+			$action_error_txt .= "<br>xen" . $a["vps_xen_name"] . " " . $a["vps_server_hostname"];
 			$ret_val = false;
 		}
 
 		// Check against the SSLIP list
-		if($_REQUEST["action"] == "ssl_ip_list_edit"){
+		if($_REQUEST["action"] == "dedicated_ip_list_edit"){
 			$q = "SELECT * FROM $pro_mysql_dedicated_ips_table WHERE ip_addr='$test_ip' AND id != '". $_REQUEST["id"] ."';";
 		}else{
 			$q = "SELECT * FROM $pro_mysql_dedicated_ips_table WHERE ip_addr='$test_ip';";
@@ -530,13 +801,15 @@ function checkIPAssigned(){
 		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__file__." sql said: ".mysql_error());
 		$n = mysql_num_rows($r);
 		if($n != 0){
+			$a = mysql_array($r);
 			$action_error_txt = _("The IP address $test_ip is already assigned to a dedicated server: cannot assign this one!");
+			$action_error_txt .= "<br>". _("Server hostname: ") . $a["dedicated_server_hostname"];
 			$ret_val = false;
 		}
 
 
 		// Check against the dedicated IP list
-		if($_REQUEST["action"] != "dedicated_ip_list_edit" && $_REQUEST["action"] != "dedicated_ip_list_new"){
+		if($_REQUEST["action"] == "ssl_ip_list_edit"){
 			$q = "SELECT * FROM $pro_mysql_ssl_ips_table WHERE ip_addr='$test_ip' AND id != '". $_REQUEST["id"] ."';";
 		}else{
 			$q = "SELECT * FROM $pro_mysql_ssl_ips_table WHERE ip_addr='$test_ip';";
@@ -544,7 +817,7 @@ function checkIPAssigned(){
 		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__file__." sql said: ".mysql_error());
 		$n = mysql_num_rows($r);
 		if($n != 0){
-			$action_error_txt = _("The IP address $test_ip is already assigned to an SSL site: cannot assign this one!");
+			echo $action_error_txt = _("The IP address $test_ip is already assigned to an SSL site: cannot assign this one!");
 			$ret_val = false;
 		}
 
@@ -558,6 +831,7 @@ function drawVPSServerConfig(){
 	global $pro_mysql_vps_server_table;
 	global $pro_mysql_list_table;
 	global $pro_mysql_vps_server_lists_table;
+	global $pro_mysql_ip_pool_table;
 	global $rub;
 	global $sousrub;
 	global $cc_code_array;
@@ -616,6 +890,23 @@ function drawVPSServerConfig(){
 	$out .= $vps_server_list;
 
 	if(isset($_REQUEST["edithost"])){
+		$q = "SELECT * FROM $pro_mysql_ip_pool_table";
+		$r = mysql_query($q) or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n == 0){
+			$out .= "<font color=\"red\">". _("Warning: no IP pool in the database!") ."</font>";
+		}
+		unset($my_pool_values);
+		unset($my_pool_text);
+		$my_pool_values = array();
+		$my_pool_text = array();
+		$my_pool_values[] = 0;
+		$my_pool_text[] = "Not set";
+		for($i=0;$i<$n;$i++){
+			$a = mysql_fetch_array($r);
+			$my_pool_values[] = $a["id"];
+			$my_pool_text[] = $a["location"] . " " . $a["ip_addr"] . " " . $a["netmask"];
+		}
 		$q = "SELECT * FROM $pro_mysql_vps_server_table WHERE id='".$_REQUEST["edithost"]."';";
 		$r = mysql_query($q);
 		$a = mysql_fetch_array($r);
@@ -635,10 +926,16 @@ function drawVPSServerConfig(){
 					"legend" => "id"),
 				"vps_xen_name" => array(
 					"type" => "text",
+					"help" => _("Names of your VPS should always be like 01, 02, 03 ... (including the leading zero)."),
 					"legend" => _("VPS xen number")),
 				"ip_addr" => array(
 					"type" => "text",
 					"legend" => _("IPs addrs")),
+				"ip_pool_id" => array(
+					"type" => "popup",
+					"legend" => _("IP Pool"),
+					"values" => $my_pool_values,
+					"display_replace" => $my_pool_text),
 				"available" => array(
 					"type" => "radio",
 					"legend" => _("Available"),
@@ -700,6 +997,15 @@ function drawRegistrySelection(){
 	return $out;
 }
 
+function generalDaemonCallback(){
+        global $pro_mysql_domain_table;
+        global $pro_mysql_cronjob_table;
+        #$q = "UPDATE $pro_mysql_domain_table SET generate_flag='yes';";
+        #$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+        $q = "UPDATE $pro_mysql_cronjob_table SET restart_apache='yes', gen_vhosts='yes';";
+        $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+}
+
 function drawGeneralConfig(){
 	global $cc_code_array;
 
@@ -719,11 +1025,6 @@ function drawGeneralConfig(){
 				"type" => "radio",
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No"))),
-			"send_passwords_in_emails" => array(
-				"legend" => _("Send passwords in registration emails: "),
-				"type" => "radio",
-				"values" => array("yes","no"),
-				"display_replace" => array(_("Yes"),_("No"))),
 			"use_ssl" => array(
 				"legend" => _("Use SSL: "),
 				"type" => "radio",
@@ -758,6 +1059,7 @@ function drawGeneralConfig(){
 		"title" => _("Daemon"),
 		"action" => "general_config_daemon",
 		"forward" => array("rub"),
+                "edit_callback" => "generalDaemonCallback",
 		"cols" => array (
 			"mta_type" => array(
 				"legend" => "MTA <a href=\"http://pl.wikipedia.org/wiki/MTA\" target=\"_blank\">*</a> : ",
@@ -768,6 +1070,11 @@ function drawGeneralConfig(){
 				"legend" => _("Use cyrus: "),
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No"))),
+			"use_advanced_lists_tunables" => array(
+				"type" => "radio",
+				"legend" => _("Show advanced mailing list options: "),
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
 			"use_webalizer" => array(
 				"type" => "radio",
 				"legend" => _("Use webalizer: "),
@@ -780,7 +1087,7 @@ function drawGeneralConfig(){
 				"display_replace" => array(_("Yes"),_("No"))),
 			"use_awstats" => array(
 				"type" => "radio",
-				"legend" => _("Use awstats: "),
+				"legend" => "(<a href=\"http://dtcsupport.gplhost.com/PmWiki/Why-not-using-awstats\">AWStats armful?</a>) " . _("Use awstats: "),
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No"))),
 			"use_visitors" => array(
@@ -788,6 +1095,11 @@ function drawGeneralConfig(){
 				"legend" => _("Use visitors: "),
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No"))),
+			"user_mysql_prepend_admin_name" => array(
+				"type" => "radio",
+				"legend" => _("Prepend admin name to db names: "),
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
 			"user_mysql_type" => array(
 				"legend" => _("Location of user's database: "),
 				"type" => "radio",
@@ -801,6 +1113,20 @@ function drawGeneralConfig(){
 				"type" => "text"),
 			"user_mysql_root_pass" => array(
 				"legend" => _("User MySQL root password: "),
+				"type" => "text"),
+			"autogen_webmail_alias" => array(
+				"legend" => _("Generate a global /webmail alias: "),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
+			"autogen_webmail_type" => array(
+				"legend" => _("Type of webmail for the /webmail alias: "),
+				"type" => "radio",
+				"display_replace" => array("Roundcube","Squirrelmail"),
+				"values" => array("roundcube","squirrelmail")),
+			"apache_directoryindex" => array(
+				"legend" => _("Apache DirectoryIndex: "),
+				"size" => "50",
 				"type" => "text")));
 	$out .= configEditorTemplate ($dsc);
 
@@ -911,16 +1237,20 @@ function drawNamedConfig(){
 				"legend" => _("IP of the master DNS to be written in the named.slavezones.conf:"),
 				"type" => "text",
 				"size" => "20"),
-			"use_cname_for_subdomains" => array(
+/*			"use_cname_for_subdomains" => array(
 				"legend" => _("Use CNAME instead of A record for subdomains:"),
 				"type" => "radio",
 				"values" => array("yes","no"),
-				"display_replace" => array(_("Yes"),_("No"))),
+				"display_replace" => array(_("Yes"),_("No"))), */
 			"autogen_default_subdomains" => array(
 				"legend" => _("Auto-generate default subdomains (mail, pop, imap, smtp, ftp, list):"),
 				"type" => "radio",
 				"values" => array("yes","no"),
 				"display_replace" => array(_("Yes"),_("No"))),
+			"autogen_subdomain_list" => array(
+				"legend" => _("Auto-generate subdomain list (separated by |):"),
+				"type" => "text",
+				"size" => "50"),
 			"ip_allowed_dns_transfer" => array(
 				"legend" => _("List the DNS server IPs allowed to do zone<br>
 transfers separated by &quot;|&quot; (pipe)<br>
@@ -931,6 +1261,22 @@ transfers separated by &quot;|&quot; (pipe)<br>
 				"legend" => _("Defaut TTL for your zonefiles:"),
 				"type" => "text",
 				"size" => "10"),
+			"named_soa_refresh" => array(
+				"legend" => _("SOA refresh value: "),
+				"type" => "text",
+				"size" => "16"),
+			"named_soa_retry" => array(
+				"legend" => _("SOA retry value: "),
+				"type" => "text",
+				"size" => "16"),
+			"named_soa_expire"  => array(
+				"legend" => _("SOA expire value: "),
+				"type" => "text",
+				"size" => "16"),
+			"named_soa_default_ttl" => array(
+				"legend" => _("SOA default ttl value: "),
+				"type" => "text",
+				"size" => "16"),
 			"domainkey_publickey_filepath" => array(
 				"legend" => _("Full path to location of the public.key file for DomainKey support:"),
 				"type" => "text",
@@ -1118,7 +1464,28 @@ function drawDTCpayConfig(){
 
 	$out = "";
 
+	$dsc = array(
+		"title" => _("Web host subdomain registration"),
+		"action" => "own_domain_edit",
+		"forward" => array("rub","sousrub"),
+		"cols" => array(
+			"provide_own_domain_hosts" => array(
+				"legend" => _("Allow registration of subdomain of the main domain: "),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))) ));
+	$out .= configEditorTemplate($dsc);
 
+	$dsc = array(
+		"title" => _("Affiliation"),
+		"action" => "affiliate_edit",
+		"forward" => array("rub","sousrub"),
+		"cols" => array(
+			"affiliate_return_domain" => array(
+				"legend" => _("Domain name for affiliation return URL:"),
+				"type" => "text"
+				)));
+	$out .= configEditorTemplate($dsc);
 
 	$dsc = array(
 		"title" => _("Secure payment configuration"),
@@ -1135,6 +1502,47 @@ function drawDTCpayConfig(){
 				"size" => "6")));
 	$out .= configEditorTemplate ($dsc,"secpay");
 
+	$dsc = array(
+		"title" => _("Cheques and wire transfers:"),
+		"action" => "cheques_edit",
+		"forward" => array("rub","sousrub"),
+		"cols" => array(
+			"accept_cheques" => array (
+				"legend" => _("Accept cheques: "),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
+			"cheques_flat_fees" => array (
+				"legend" => _("Flat fee for accepting cheques: "),
+				"size" => "6",
+				"type" => "text"),
+			"cheques_to_label" => array (
+				"legend" => _("Cheques Payable To: "),
+				"size" => "30",
+				"type" => "text"),
+			"cheques_send_address" => array (
+				"legend" => _("Instructions to send cheques: "),
+				"cols" => "60",
+				"rows" => "7",
+				"type" => "textarea"),
+			"accept_wiretransfers" => array (
+				"legend" => _("Accept wire transfers to bank: "),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
+			"wiretransfers_flat_fees" => array (
+				"legend" => _("Flat fee for accepting wire transfers: "),
+				"size" => "6",
+				"type" => "text"),
+			"wiretransfers_bank_details" => array (
+				"legend" => _("Bank account details: "),
+				"cols" => "60",
+				"rows" => "12",
+				"type" => "textarea")
+			)
+		);
+	$out .= configEditorTemplate ($dsc,"secpay");
+
 //  -- zion --
 	$dsc = array(
 		"title" => "WebMoney:",
@@ -1184,6 +1592,11 @@ function drawDTCpayConfig(){
 				"legend" => _("PayPal flat fee: "),
 				"type" => "text",
 				"size" => "6"),
+			"paypal_validate_with" => array(
+				"legend" => _("Validate payment if amount is greater or equal to: "),
+				"type" => "radio",
+				"values" => array("total","mc_gross"),
+				"display_replace" => array(_("Grand total"),_("Gross amount"))),
 			"paypal_sandbox" => array(
 				"legend" => _("Use the sandbox test server: "),
 				"type" => "radio",
@@ -1200,6 +1613,49 @@ function drawDTCpayConfig(){
 				"size" => "6")));
 	$out .= configEditorTemplate ($dsc,"secpay");
 
+	$dsc = array(
+		"title" => "MoneyBookers (currently in development):",
+		"action" => "payment_gateway_moneybookers_edit",
+		"forward" => array("rub","sousrub"),
+		"cols" => array(
+			"use_moneybookers" => array(
+				"legend" => _("Use MoneyBookers: "),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
+			"moneybookers_autovalidate" => array(
+				"legend" => _("Validate new account if paid: "),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
+			"moneybookers_email" => array(
+				"legend" => _("MoneyBookers business account email: "),
+				"type" => "text",
+				"size" => "30"),
+			"moneybookers_rate" => array(
+				"legend" => _("MoneyBookers fee rate: "),
+				"type" => "text",
+				"size" => "6"),
+			"moneybookers_flat" => array(
+				"legend" => _("MoneyBookers flat fee: "),
+				"type" => "text",
+				"size" => "6"),
+			"moneybookers_validate_with" => array(
+				"legend" => _("Validate payment if amount is greater or equal to: "),
+				"type" => "radio",
+				"values" => array("total","mc_gross"),
+				"display_replace" => array(_("Grand total"),_("Gross amount"))),
+			"moneybookers_sandbox" => array(
+				"legend" => _("Use the sandbox test server: "),
+				"type" => "radio",
+				"values" => array("yes","no"),
+				"display_replace" => array(_("Yes"),_("No"))),
+			"moneybookers_sandbox_email" => array(
+				"legend" => _("MoneyBookers test account email (sandbox): "),
+				"type" => "text",
+				"size" => "6")));
+	$out .= configEditorTemplate ($dsc,"secpay");
+
 	$dsc = array(
 		"title" => "eNETS:",
 		"action" => "payment_gateway_enets_edit",
@@ -1579,6 +2035,8 @@ function drawDTCConfigForm(){
 		return drawSSLIPConfig();
 	case "ip_pool":
 		return drawIPPoolConfig();
+	case "nagios":
+		return drawNagiosConfig();
 	case "dedicatedip":
 		return drawDedicatedIPConfig();
 	case "zonefile":
