@@ -424,7 +424,7 @@ function drawRenewalTables (){
 				$out .= "<table cellspacing=\"0\" cellpadding=\"2\" border=\"1\">
 				<tr><td>"._("Product")."</td><td>". _("Client ID") ."</td><td>". _("Client")."</td><td>". _("Service country")."</td>
 				<td>"._("Client country")."</td>
-				<td>". _("VAT collected")."</td><td>". _("Period")."</td><td>". _("Payment date")."</td><td>"._("Total")."</td>
+				<td>". _("VAT collected")."</td><td>". _("Period")."</td><td>". _("Payment date")."</td><td>"._("Total")."</td><td>". _("Payment method")."</td>
 				<td>". _("Action") ."</td></tr>";
 				for($i=0;$i<$n;$i++){
 					$a = mysql_fetch_array($r);
@@ -461,10 +461,15 @@ function drawRenewalTables (){
 					$n2 = mysql_num_rows($r2);
 					if($n2 != 1){
 						$payment_txt = _("Payment not found");
+						$payment_type = _("Payment not found");
 						$vat_collected = _("VAT not found");
 					}else{
 						$a2 = mysql_fetch_array($r2);
 						$payment_txt = $a2["paiement_total"]. " " . $a2["currency"];
+						$payment_type = $a2["paiement_type"];
+						if($payment_type == "online"){
+							$payment_type .= ": ".$a2["secpay_site"];
+						}
 						$vat_collected = $a2["paiement_total"] * $a2["vat_rate"] / 100 ;
 					}
 					if($a["last_expiry_date"] == "0000-00-00"){
@@ -476,6 +481,7 @@ function drawRenewalTables (){
 					$out .= "<tr><td>$product_txt</td><td>$client_id_txt</td><td>$client_name</td><td>".$a["country_code"]."</td>
 					<td>$client_country</td>
 					<td>$vat_collected</td><td>$last_expiry_date -> $new_expiry_date</td><td>".$a["date"]."</td><td>$payment_txt</td>
+					<td>$payment_type</td>
 					<td><a href=\"".$_SERVER["PHP_SELF"]."?rub=$rub&date=".$_REQUEST["date"]."&action=nuke_payment&completedorders_id=".$a["id"]."\">"._("Delete")."</a></tr>";
 				}
 				$out .= "</table>";
@@ -559,7 +565,11 @@ function drawRenewalTables (){
 			}else{
 				$papoum = explode('-',$period);
 				$months = $papoum[1];
-				$total_dedicated += $price / $months;
+				if($months == 0){
+					echo "A dedicated server product has zero for the number of month to renew<br>";
+				}else{
+					$total_dedicated += $price / $months;
+				}
 			}
 		}
 
@@ -574,12 +584,12 @@ function drawRenewalTables (){
 		// Show a quick history of payments
 		$year = date("Y");
 		$month = date("m");
-		$cur_year = $year - 1;
+		$cur_year = $year - 2;
 		$cur_month = $month;
 		$p_history = "";
 		$p_history .= "<table cellspacing=\"1\" cellpadding=\"1\" border=\"1\">
 		<tr><td>". _("Period") ."</td><td>". _("Amount") ."</td><td>"._("VAT collected")."</td><td>"._("Payment gateway cost")."</td><td>"._("Profit")."</td></tr>";
-		for($i=0;$i<13;$i++){
+		for($i=0;$i<25;$i++){
 			$q2 = "SELECT $pro_mysql_pay_table.paiement_total,$pro_mysql_pay_table.vat_rate,$pro_mysql_pay_table.paiement_cost
 			FROM $pro_mysql_pay_table,$pro_mysql_completedorders_table
 			WHERE $pro_mysql_pay_table.vat_rate!='0.00'
@@ -625,11 +635,14 @@ function drawRenewalTables (){
 		}
 		$p_history .= "</table>";
 
+		$p_active_prods = "<img src=\"active_prods_graph.php?graph=year\"><br>
+<img src=\"active_prods_graph.php?graph=month\">";
 
 		// Layout the recuring stat and the effective payment statistics
-		$out .= "<table cellspacing=\"1\" cellpadding=\"4\" border=\"0\">
-		<tr><td>$p_history</td>
-		<td valign=\"top\">$p_renewal</td></tr></table>";
+		$out .= "<table cellspacing=\"1\" cellpadding=\"4\" border=\"0\" width=\"100%\">
+		<tr valign=\"top\"><td valign=\"top\" width=\"50%\">$p_history</td>
+		<td valign=\"top\">$p_renewal</td>
+		<td valign=\"top\">$p_active_prods</td></tr></table>";
 
 		$out .= "<h3>". _("Shared hosting renewals:") ."</h3>";
 		$q = "SELECT * FROM $pro_mysql_admin_table WHERE expire < '".date("Y-m-d")."' AND id_client!='0' AND expire !='0000-00-00' ORDER BY expire;";
