@@ -46,6 +46,7 @@ function deleteVPS($id){
 	global $pro_mysql_vps_table;
 	global $pro_mysql_vps_ip_table;
 	global $pro_mysql_vps_stats_table;
+	global $pro_mysql_cronjob_table;
 
 	$q = "SELECT * FROM $pro_mysql_vps_table WHERE id='$id';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
@@ -60,13 +61,16 @@ function deleteVPS($id){
 	$q = "DELETE FROM $pro_mysql_vps_table WHERE id='".$_REQUEST["id"]."';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 
-	$q = "DELETE FROM $pro_mysql_vps_stats_table WHERE vps_server_hostname='".$vps["vps_server_hostname"]."' AND vps_xen_name='".$vps["vps_xen_name"]."';";
+	$q = "DELETE FROM $pro_mysql_vps_stats_table WHERE vps_server_hostname='".$vps["vps_server_hostname"]."' AND vps_xen_name='xen".$vps["vps_xen_name"]."';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 
 	remoteVPSAction($vps["vps_server_hostname"],$vps["vps_xen_name"],"destroy_vps");
 	remoteVPSAction($vps["vps_server_hostname"],$vps["vps_xen_name"],"kill_vps_disk");
 
 	VPS_Server_Subscribe_To_Lists($vps["vps_server_hostname"]);
+
+	$adm_query = "UPDATE $pro_mysql_cronjob_table SET gen_nagios='yes' WHERE 1;";
+	mysql_query($adm_query);
 }
 
 if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "delete_a_vps"){
@@ -115,10 +119,9 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "add_vps_to_user"){
 	}
 	$a = mysql_fetch_array($r);
 
-	$q = "UPDATE $pro_mysql_vps_ip_table SET vps_xen_name='".$a["vps_xen_name"]."', available='no' WHERE ip_addr='".$_REQUEST["vps_server_ip"]."';";
+	$q = "UPDATE $pro_mysql_vps_ip_table SET available='no' WHERE vps_xen_name='".$a["vps_xen_name"]."' AND vps_server_hostname='".$a["vps_server_hostname"]."';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 
-
 	$q = "SELECT * FROM $pro_mysql_product_table WHERE id='".$_REQUEST["product_id"]."';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
@@ -157,7 +160,8 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "import_domain"){
 	$uploaded_full_path = $adm_path."/".$uploaded_file;
 //	echo "Importing domain file: ".$_FILES["domain_import_file"]["name"]." for user $adm_login";
 	move_uploaded_file($_FILES["domain_import_file"]["tmp_name"],$uploaded_full_path);
-	domainImport($uploaded_full_path,$adm_login);
+	domainImport($uploaded_full_path,$adm_login,$adm_pass);
+	unlink($uploaded_full_path);
 
 	// Tell the cron job to activate the changes
 	$adm_query = "UPDATE $pro_mysql_cronjob_table SET qmail_newu='yes',restart_qmail='yes',reload_named='yes',
@@ -301,13 +305,13 @@ if(isset($_REQUEST["newadminuser"]) && $_REQUEST["newadminuser"]=="Ok"){
 
 // action=delete_waiting_user&reqadm_login=tom
 if(isset($_REQUEST["action"]) && $_REQUEST["action"]=="delete_waiting_user"){
-	$q = "DELETE FROM $pro_mysql_new_admin_table WHERE reqadm_login='".$_REQUEST["reqadm_login"]."';";
+	$q = "DELETE FROM $pro_mysql_new_admin_table WHERE id='".$_REQUEST["reqadm_id"]."';";
 	mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 }
 
 // action=valid_waiting_user&reqadm_login=tom
 if(isset($_REQUEST["action"]) && $_REQUEST["action"]=="valid_waiting_user"){
-	validateWaitingUser($_REQUEST["reqadm_login"]);
+	validateWaitingUser($_REQUEST["reqadm_id"]);
 	triggerDomainListUpdate();
 }
 
