@@ -56,7 +56,9 @@ if($argc > 6){
         }
 }
 
+chdir(dirname(__FILE__));
 require("dtc_db.php");
+require("../shared/dtc_version.php");
 
 mysql_connect("$pro_mysql_host", "$pro_mysql_login", "$pro_mysql_pass")or die ("Cannot connect to $pro_mysql_host");
 mysql_select_db("$pro_mysql_db")or die ("Cannot select db: $pro_mysql_db");
@@ -222,6 +224,12 @@ if($n > 0){
 	echo "\n";
 }
 
+# Check all expiration date that are 0000-00-00 and set them to the current date + 10 years
+$year = date("Y");
+$year = $year + 10;
+$q = "UPDATE admin SET expire='".$year."-".date("m-d")."' WHERE expire='0000-00-00';";
+$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+
 // Period was a date before, but it doesn't work with MySQL 5, so we are switching it to a varchar //
 $q = "ALTER TABLE `product` CHANGE `period` `period` VARCHAR( 12 ) NOT NULL DEFAULT '0001-00-00';";
 $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
@@ -251,19 +259,27 @@ $q = "ALTER TABLE vps_stats CHANGE `network_in_count` `network_in_count` bigint(
 $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 $q = "ALTER TABLE vps_stats CHANGE `network_out_count` `network_out_count` bigint(22) default NULL";
 $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
-$q = "ALTER TABLE vps_stats CHANGE `network_in_last` `network_in_last` bigint(22) default NULL";
-$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
-$q = "ALTER TABLE vps_stats CHANGE `network_out_last` `network_out_last` bigint(22) default NULL";
-$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 $q = "ALTER TABLE vps_stats CHANGE `swapio_count` `swapio_count` bigint(22) default NULL";
 $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 $q = "ALTER TABLE vps_stats CHANGE `diskio_count` `diskio_count` bigint(22) default NULL";
 $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
-$q = "ALTER TABLE vps_stats CHANGE `swapio_last` `swapio_last` bigint(22) default NULL";
+
+// Set the correct default last_used_lang feild
+$q = "ALTER TABLE new_admin CHANGE last_used_lang last_used_lang varchar(32) NOT NULL default 'en_US.UTF-8'";
 $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
-$q = "ALTER TABLE vps_stats CHANGE `diskio_last` `diskio_last` bigint(22) default NULL";
+$q = "ALTER TABLE admin CHANGE last_used_lang last_used_lang varchar(32) NOT NULL default 'en_US.UTF-8'";
 $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 
+// Change domain parking types
+$q = "ALTER TABLE `domain` CHANGE `domain_parking_type` `domain_parking_type` enum('redirect','same_docroot','serveralias') NOT NULL default 'redirect'";
+$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+
+// Alter the default shell value for FreeBSD, as the path will be in /usr/local
+if($conf_unix_type == "bsd"){
+	$q = "ALTER TABLE ssh_access CHANGE `shell` `varchar(64) NOT NULL default '/usr/local/bin/dtc-chroot-shell'";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+}
+
 $q = "SELECT * FROM config";
 $r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 $n = mysql_num_rows($r);
@@ -272,9 +288,12 @@ if($n != 1){
 }
 $config_vals = mysql_fetch_array($r);
 
-# Sets old install of ssh shell path to be /usr/bin/dtc-chroot-shell and not /bin/dtc-chroot-shell
-$q = "UPDATE ssh_access SET shell='/usr/bin/dtc-chroot-shell' WHERE shell='/bin/dtc-chroot-shell';";
-$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+// Get rid of old skins...
+$zeskin = $config_vals["skin"];
+if( $zeskin == "green2" || $zeskin == "iglobal" || $zeskin == "green_gpl" || $zeskin == "darkblue" || $zeskin == "frame" || $zeskin == "green" || $zeskin == "ruffdogs_mozilla" || $zeskin == "tex" || $zeskin == "muedgrey"){
+	$q = "UPDATE config SET skin='bwoup';";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+}
 
 // Iterate on all mailing lists to set the correct recipient delimiter
 echo "-> Changing all recipient delimiter for mailing lists: ";
