@@ -40,11 +40,13 @@ named_slavefile_path varchar(255) NOT NULL default 'named.slavezones.conf',
 named_slavezonefiles_path varchar(255) NOT NULL default 'slave_zones',
 named_zonefiles_path varchar(255) NOT NULL default 'zones',
 autogen_default_subdomains enum('yes','no') NOT NULL default 'yes',
+autogen_subdomain_list varchar(255) NOT NULL default 'pop|imap|mail|smtp|ftp',
+autogen_webmail_alias enum('yes','no') NOT NULL default 'yes',
+autogen_webmail_type enum('squirrelmail','roundcube') NOT NULL default 'squirrelmail',
 backup_script_path varchar(255) NOT NULL default 'backup.bash',
 bakcup_path varchar(255) NOT NULL default '/mnt/backup',
 webalizer_stats_script_path varchar(255) NOT NULL default 'webalizer.bash',
 use_javascript enum('yes','no') NOT NULL default 'yes',
-send_passwords_in_emails enum('yes','no') NOT NULL default 'no',
 use_ssl enum('yes','no') NOT NULL default 'no',
 use_nated_vhost enum('yes','no') NOT NULL default 'no',
 nated_vhost_ip varchar(16) NOT NULL default '192.168.0.2',
@@ -52,6 +54,7 @@ mta_type enum('qmail','postfix') NOT NULL default 'qmail',
 use_cyrus enum('yes','no') NOT NULL default 'no',
 use_amavis enum('yes','no') NOT NULL default 'yes',
 use_clamav enum('yes','no') NOT NULL default 'yes',
+use_advanced_lists_tunables enum('yes','no') NOT NULL default 'no',
 use_webalizer enum('yes','no') NOT NULL default 'yes',
 use_awstats enum('yes','no') NOT NULL default 'no',
 use_visitors enum('yes','no') NOT NULL default 'no',
@@ -66,8 +69,6 @@ srs_live_key varchar(255) NOT NULL default '',
 srs_test_key varchar(255) NOT NULL default '',
 srs_enviro enum('LIVE','TEST') NOT NULL default 'TEST',
 srs_crypt enum('DES','BLOWFISH') NOT NULL default 'DES',
-root_admin_random_pass varchar(128) NOT NULL default '',
-pass_expire int(12) NOT NULL default '0',
 use_registrar_api enum('yes','no') NOT NULL default 'no',
 ftp_backup_host varchar(255) NOT NULL default '',
 ftp_backup_login varchar(255) NOT NULL default '',
@@ -90,6 +91,7 @@ dtc_system_username varchar (64) NOT NULL default 'dtc',
 dtc_system_gid varchar (16) NOT NULL default '1001',
 dtc_system_groupname varchar (64) NOT NULL default 'nogroup',
 selling_conditions_url varchar (255) NOT NULL default 'none',
+user_mysql_prepend_admin_name enum('yes','no') NOT NULL default 'no',
 user_mysql_type enum('localhost','distant') NOT NULL default 'localhost',
 user_mysql_host varchar (255) NOT NULL default 'localhost',
 user_mysql_root_login varchar (255) NOT NULL default 'none',
@@ -98,5 +100,20 @@ user_mysql_client varchar (255) NOT NULL default '%',
 `recipient_delimiter` varchar(4) NOT NULL default '\+',
 this_server_country_code varchar (4) NOT NULL default 'US',
 message_subject_header varchar (255) NOT NULL default '[DTC]',
+apache_directoryindex varchar(255) NOT NULL default 'index.php index.cgi index.pl index.htm index.html index.php4',
+named_soa_refresh varchar (16) NOT NULL default '2H',
+named_soa_retry varchar (16) NOT NULL default '60M',
+named_soa_expire varchar (16) NOT NULL default '1W',
+named_soa_default_ttl varchar (16) NOT NULL default '24H',
+provide_own_domain_hosts enum('yes','no') NOT NULL default 'no',
+nagios_host varchar(255) NOT NULL default '',
+nagios_username varchar(255) NOT NULL default '',
+nagios_config_file_path varchar(255) NOT NULL default '',
+nagios_restart_command varchar(255) NOT NULL default 'sudo /etc/init.d/nagios2 restart',
+affiliate_return_domain varchar(255) NOT NULL default 'www.example.com',
+support_ticket_email varchar(255) NOT NULL default 'support',
+support_ticket_domain varchar(255) NOT NULL default 'default',
+all_customers_list_email varchar(255) NOT NULL default 'support',
+all_customers_list_domain varchar(255) NOT NULL default 'default',
 UNIQUE KEY unicrow (unicrow)
 )MAX_ROWS = 1 TYPE=MyISAM
