@@ -9,7 +9,6 @@ function register_user($adding_service="no"){
 	global $conf_selling_conditions_url;
 
 	global $conf_message_subject_header;
-	global $conf_send_passwords_in_emails;
 
 	global $secpayconf_currency_letters;
 
@@ -20,6 +19,7 @@ function register_user($adding_service="no"){
 	&& (!isset($_REQUEST["reqadm_pass"]) || $_REQUEST["reqadm_pass"] == "" )
 	&& (!isset($_REQUEST["reqadm_pass2"]) || $_REQUEST["reqadm_pass2"] == "")
 	&& (!isset($_REQUEST["domain_name"]) || $_REQUEST["domain_name"] == "")
+	&& (!isset($_REQUEST["domain_tld"]) || $_REQUEST["domain_tld"] == "")
 	&& (!isset($_REQUEST["familyname"]) || $_REQUEST["familyname"] == "")
 	&& (!isset($_REQUEST["firstname"]) || $_REQUEST["firstname"] == "")
 	&& (!isset($_REQUEST["email"]) || $_REQUEST["email"] == "")
@@ -53,7 +53,7 @@ function register_user($adding_service="no"){
 	}
 
 	// Do field format checking and escaping for all fields
-	if(!isMailbox($_REQUEST["reqadm_login"])){
+	if( !ereg("^([a-zA-Z0-9]+)([._a-zA-Z0-9-]+)\$",$_REQUEST["reqadm_login"]) ){
 		$ret["err"] = 2;
 		$ret["mesg"] = _("User login format incorrect. Please use letters and numbers only and from 4 to 16 chars.") ;
 		return $ret;
@@ -73,16 +73,26 @@ function register_user($adding_service="no"){
 		$ret["mesg"] = _("Passwords 1 and 2 do not match!") ;
 		return $ret;
 	}
+
+	if($_REQUEST["domain_name"] == "" || !isTLD($_REQUEST["domain_tld"])){
+		$domain_tld = "";
+	}else{
+		$domain_tld = $_REQUEST["domain_tld"];
+	}
+
 	// If shared or ssl hosting, we MUST do type checkings
-	if($db_product["heb_type"] == "shared" || $db_product["heb_type"] == "ssl"){
-		if(!isHostnameOrIP($_REQUEST["domain_name"])){
+	if($db_product["heb_type"] == "shared" || $db_product["heb_type"] == "ssl" || $db_product["heb_type"] == "dedicated"){
+		if(!isHostnameOrIP($_REQUEST["domain_name"].$_REQUEST["domain_tld"])){
 			$ret["err"] = 2;
 			$ret["mesg"] = _("Domain name seems to be incorrect.") ;
 			return $ret;
 		}
-	// If not a shared or ssl account, we don't care if it's umpty, but we take care of mysql insertion anyway
+	// If not a shared, a dedicated or ssl account, it's a VPS:
+	// we don't care if it's umpty, but we take care of mysql insertion anyway
+	// so if there is a domain name, then we check it's consistency, but we don't
+	// do much more if there's nothing...
 	}else{
-		if($_REQUEST["domain_name"] != "" && (!isHostnameOrIP($_REQUEST["domain_name"]))){
+		if($_REQUEST["domain_name"].$domain_tld != "" && (!isHostnameOrIP($_REQUEST["domain_name"].$domain_tld))){
 			$ret["err"] = 2;
 			$ret["mesg"] = _("Domain name seems to be incorrect.") ;
 			return $ret;
@@ -335,7 +345,7 @@ maxmind_output$vps_add1
 )
 VALUES('".$_REQUEST["reqadm_login"]."',
 '".$_REQUEST["reqadm_pass"]."',
-'".$_REQUEST["domain_name"]."',
+'".$_REQUEST["domain_name"].$domain_tld."',
 '$esc_familyname',
 '$esc_firstname',
 '$esc_compname',
@@ -374,18 +384,12 @@ VALUES('".$_REQUEST["reqadm_login"]."',
 		$the_prod = $a["name"]." (".$a["price_dollar"]." $secpayconf_currency_letters)";
 	}
 
-if($conf_send_passwords_in_emails == "yes"){
-	$pass_for_email = $_REQUEST["reqadm_pass"];
-}else{
-	$pass_for_email = _("- password removed for security reasons -");
-}
-
 	$mail_content = "
 Somebody tried to register an account. Here is the details of the new user:
 
 login: ".$_REQUEST["reqadm_login"]."
-pass: ".$pass_for_email."
-domain: ".$_REQUEST["domain_name"]."
+pass: ".$_REQUEST["reqadm_pass"]."
+domain: ".$_REQUEST["domain_name"].$domain_tld."
 Company name: ".$_REQUEST["compname"]."
 First name: ".$_REQUEST["firstname"]."
 Family name: ".$_REQUEST["familyname"]."
@@ -396,7 +400,7 @@ Addr: ".$_REQUEST["address1"]." ".$_REQUEST["address2"]." ".$_REQUEST["address3"
 Zipcode: $esc_zipcode
 City: ".$_REQUEST["city"]."
 State: ".$_REQUEST["state"]."
-Contry: ".$_REQUEST["country"]."
+Country: ".$_REQUEST["country"]."
 Shopper ip: ".$_SERVER["REMOTE_ADDR"]."
 Product id: $the_prod
 Customer note: ".$_REQUEST["custom_notes"]."
@@ -410,6 +414,7 @@ $vps_mail_add1
 }
 
 function registration_form(){
+	global $conf_this_server_country_code;
         global $conf_skin;
 
 	global $pro_mysql_product_table;
@@ -419,6 +424,9 @@ function registration_form(){
 	global $conf_selling_conditions_url;
 	global $secpayconf_currency_symbol;
 
+	global $conf_main_domain;
+	global $conf_provide_own_domain_hosts;
+
 	get_secpay_conf();
 
 	if(isset($_REQUEST["product_id"]) && isRandomNum($_REQUEST["product_id"])){
@@ -441,7 +449,7 @@ function registration_form(){
 	$q = "SELECT * FROM $pro_mysql_product_table WHERE $heb_type_condition AND renew_prod_id='0' AND private='no' ORDER BY id";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
-	$prod_popup .= "<option value=\"-1\">Please select!</optioon>";
+	$prod_popup .= "<option value=\"-1\">"._("Please select!")."</optioon>";
 	for($i=0;$i<$n;$i++){
 		$a = mysql_fetch_array($r);
 		$p_jscript .= " prod_popup_htype[".$a["id"]."] = '".$a["heb_type"]."';\n";
@@ -478,6 +486,9 @@ function registration_form(){
 	if(isset($_REQUEST["domain_name"]))	$frm_domain_name = htmlspecialchars($_REQUEST["domain_name"]);
 	else	$frm_domain_name = "";
 
+	if(isset($_REQUEST["domain_tld"]))	$frm_domain_tld = htmlspecialchars($_REQUEST["domain_tld"]);
+	else	$frm_domain_tld = "";
+
 	if(isset($_REQUEST["firstname"]))	$frm_firstname = htmlspecialchars($_REQUEST["firstname"]);
 	else	$frm_firstname = "";
 
@@ -536,41 +547,50 @@ function registration_form(){
 	}
 
 	$debian_selected = " ";
+	$debiandtc_selected = " ";
 	$centos_selected = " ";
 	$gentoo_selected = " ";
 	$netbsd_selected = " ";
 	if(isset($_REQUEST["vps_os"]) && $_REQUEST["vps_os"] == "debian")	$debian_selected = " selected ";
+	if(isset($_REQUEST["vps_os"]) && $_REQUEST["vps_os"] == "debian-dtc")	$debiandtc_selected = " selected ";
 	if(isset($_REQUEST["vps_os"]) && $_REQUEST["vps_os"] == "centos")	$centos_selected = " selected ";
-	if(isset($_REQUEST["vps_os"]) && $_REQUEST["vps_os"] == "gentoo")	$gentoo_selected = " selected ";
 	if(isset($_REQUEST["vps_os"]) && $_REQUEST["vps_os"] == "netbsd")	$netbsd_selected = " selected ";
 
+	$tld_popup = "";
+	if($conf_provide_own_domain_hosts == "yes"){
+		$tld_popup = "<option value=\".$conf_main_domain\">.$conf_main_domain</option>";
+	}
+	$tld_popup .= domainNamePopup($frm_domain_tld);
+
+	$rek = "<font color=\"red\">*</font>";
+
 	$prod_popup = "<table>
 <tr>
 	<td style=\"white-space: nowrap;text-align: right;\">". _("Product") .": </td><td>".$prod_popup."</td>
 </td><tr>
 	<td style=\"white-space: nowrap;text-align: right;\"><div name=\"domname_text\" id=\"domname_text\" $domname_hidden>". _("Desired domain name") .":</div></td>
-	<td><div name=\"domname_field\" id=\"domname_field\" $domname_hidden>www.<input type=\"text\" name=\"domain_name\" value=\"$frm_domain_name\"></div></td>
+	<td><div name=\"domname_field\" id=\"domname_field\" $domname_hidden>www.<input type=\"text\" name=\"domain_name\" value=\"$frm_domain_name\"><select name=\"domain_tld\">".$tld_popup."</select></div></td>
 </tr><tr>
 	<td style=\"white-space: nowrap;text-align: right;\"><div name=\"vps_popup_text\" id=\"vps_popup_text\" $vps_hidden>". _("VPS location: ") ."</div></td>
 	<td><div name=\"vps_popup_field\" id=\"vps_popup_field\" $vps_hidden><select name=\"vps_server_hostname\">$vps_location_popup</select></div></td>
 </tr><tr>
 	<td style=\"white-space: nowrap;text-align: right;\"><div name=\"vps_ospopup_text\" id=\"vps_ospopup_text\" $vps_hidden></div></td>
 	<td><div name=\"vps_ospopup_field\" id=\"vps_ospopup_field\" $vps_hidden><select name=\"vps_os\">
-		<option value=\"debian\" $debian_selected>Debian</option>
-		<option value=\"centos\" $centos_selected>CentOS</option>
-		<option value=\"gentoo\" $gentoo_selected>Gentoo</option>
-		<option value=\"netbsd\" $netbsd_selected>NetBSD</option></select></div></td>
+		<option value=\"debian\" $debian_selected>Debian (" . _("network install with debootstrap") .")</option>
+		<option value=\"debian-dtc\" $debiandtc_selected>Debian with DTC panel (" . _("network install with debootstrap") .")</option>
+		<option value=\"centos\" $centos_selected>CentOS (" . _("network install with yum") .")</option>
+		<option value=\"netbsd\" $netbsd_selected>NetBSD (" . _("network setup with install kernel") .")</option></select></div></td>
 </tr></table>";
 
 	$login_info = "<table>
 <tr>
-	<td style=\"white-space: nowrap;text-align: right;\">"._("Login: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">"._("Login: ") . $rek ."</td>
 	<td><input type=\"text\" name=\"reqadm_login\" value=\"$frm_login\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Password: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Password: ") . $rek ."</td>
 	<td><input type=\"password\" name=\"reqadm_pass\" value=\"\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Confirm pass: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Confirm pass: ") . $rek ."</td>
 	<td><input type=\"password\" name=\"reqadm_pass2\" value=\"\"></td>
 </tr></table>";
 #	$login_skined = skin("frame",$login_info,"");
@@ -585,26 +605,26 @@ function registration_form(){
 	}
 	$client_info = "<table>
 <tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Familly name: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Familly name: ") . $rek ."</td>
 	<td><input type=\"text\" name=\"familyname\" value=\"$frm_family_name\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("First name: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("First name: ") . $rek ."</td>
 	<td><input type=\"text\" name=\"firstname\" value=\"$frm_firstname\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Is it a company: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Is it a company: ") . $rek ."</td>
 	<td><input type=\"radio\" name=\"iscomp\" value=\"yes\"$compyes>"._("Yes")."
 <input type=\"radio\" name=\"iscomp\" value=\"no\"$compno>"._("No")."</td>
 </tr><tr>
 	<td style=\"white-space: nowrap;text-align: right;\">". _("Company name: ") ."</td>
 	<td><input type=\"text\" name=\"compname\" value=\"$frm_compname\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("VAT Number: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("VAT/GST Number: ") ."</td>
 	<td><input type=\"text\" name=\"vat_num\" value=\"$frm_vat_num\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Email: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Email: ") . $rek ."</td>
 	<td><input type=\"text\" name=\"email\" value=\"$frm_email\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Phone number: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Phone number: ") . $rek ."</td>
 	<td><input type=\"text\" name=\"phone\" value=\"$frm_phone\"></td>
 </tr><tr>
 	<td style=\"white-space: nowrap;text-align: right;\">". _("Fax: ") ."</td>
@@ -613,9 +633,13 @@ function registration_form(){
 
 	$client_skined = $client_info;
 
+	if(($frm_country == "" && !isset($db_product)) || ($frm_country == "" && $db_product["heb_type"] == "shared")){
+		$frm_country = $conf_this_server_country_code;
+	}
+
 	$client_addr = "<table>
 <tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Address (line1): ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Address (line1): ") . $rek ."</td>
 	<td><input type=\"text\" name=\"address1\" value=\"$frm_addr1\"></td>
 </tr><tr>
 	<td style=\"white-space: nowrap;text-align: right;\">". _("Address (line2): ") ."</td>
@@ -624,23 +648,23 @@ function registration_form(){
 	<td style=\"white-space: nowrap;text-align: right;\">". _("Address (line3): ") ."</td>
 	<td><input type=\"text\" name=\"address3\" value=\"$frm_addr3\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Zipcode: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Zipcode: ") . $rek ."</td>
 	<td><input type=\"text\" name=\"zipcode\" value=\"$frm_zipcode\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("City: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("City: ") . $rek ."</td>
 	<td><input type=\"text\" name=\"city\" value=\"$frm_city\"></td>
 </tr><tr>
 	<td style=\"white-space: nowrap;text-align: right;\">". _("State: ") ."</td>
 	<td><input type=\"text\" name=\"state\" value=\"$frm_state\"></td>
 </tr><tr>
-	<td style=\"white-space: nowrap;text-align: right;\">". _("Country: ") ."</td>
+	<td style=\"white-space: nowrap;text-align: right;\">". _("Country: ") . $rek ."</td>
 	<td><select name=\"country\">".cc_code_popup($frm_country)."</select></td>
 </tr></table>";
 #	$addr_skined = skin("frame",$client_addr,"");
 	$addr_skined = $client_addr;
 
 	if($conf_selling_conditions_url != "none"){
-		$conditions = "<input type=\"checkbox\" name=\"condition\" value=\"yes\"> ". _("I agree to the") ." <a href=\"$conf_selling_conditions_url\">". _("selling conditions") ."</a>";
+		$conditions = "<input type=\"checkbox\" name=\"condition\" value=\"yes\"> " . $rek  . _("I agree to the") ." <a href=\"$conf_selling_conditions_url\">". _("selling conditions") ."</a>";
 	}else{
 		$conditions = "";
 	}
@@ -707,7 +731,9 @@ function hostingProductChanged(){
 	}
 }
 
-</script>
+</script><br>
+<br>
+<i>" . _("Feilds with a <font color=\"red\">*</font> are mandatory.") . "</i><br>
 <form name=\"newuser_form\" action=\"".$_SERVER["PHP_SELF"]."\" methode=\"post\">
 <input type=\"hidden\" name=\"action\" value=\"new_user_request\">
 <table>
@@ -715,9 +741,9 @@ function hostingProductChanged(){
 	<td valign=\"top\"><h3>". _("Product:") ."</h3>
 	$prod_popup<br>
 <h3>". _("Login info") .":</h3> ".$login_skined."</td>
-	<td width=\"4\" background=\"gfx/skin/frame/border_2.gif\"></td>
+	<td width=\"4\" background=\"gfx/border_2.gif\"></td>
 	<td valign=\"top\"><h3>". _("Client info") ."</h3> $client_skined</td>
-	<td width=\"4\" background=\"gfx/skin/frame/border_2.gif\"></td>
+	<td width=\"4\" background=\"gfx/border_2.gif\"></td>
 	<td valign=\"top\"><h3>". _("Customer's address") ."</h3> $addr_skined</td>
 </tr></table>
 $conditions
@@ -728,7 +754,7 @@ $conditions
 	<td><input type=\"submit\" name=\"Login\" value=\"Register\"></td>
 </tr>
 </table>
-</form>";
+</form>" ;
 
 //	return $login_skined;
 	return $HTML_admin_edit_data;
