@@ -12,6 +12,7 @@ function renew_form(){
 	global $pro_mysql_vps_server_table;
 
 	global $conf_webmaster_email_addr;
+	global $conf_message_subject_header;
 	global $conf_this_server_country_code;
 
 	global $secpayconf_currency_letters;
@@ -56,7 +57,7 @@ function renew_form(){
 	$prod_id = $a["id"];
 
 	$form = "<b><u>". _("Renewal for login:") ."</u></b> ".$_REQUEST["adm_login"]."<br>";
-	$form .= "<b><u>". _("Product to renew:") ."</u></b> ".$a["name"]." (".$a["price_dollar"]." $secpayconf_currency_letters)<br><br>";
+	$form .= "<b><u>". _("Product to renew:") ."</u></b> ".$a["name"]." (".number_format($a["price_dollar"], 2)." $secpayconf_currency_letters)<br><br>";
 
 	switch($_REQUEST["renew_type"]){
 	case "vps":
@@ -175,7 +176,8 @@ Service country: $country
 	}
 
 	$headers = "From: DTC Robot <$conf_webmaster_email_addr>";
-	mail($conf_webmaster_email_addr, "[DTC] Somebody tried to renew", $mail_content, $headers);
+	$subject = $admin["adm_login"] . " tried to renew $the_prod";
+	mail($conf_webmaster_email_addr, "$conf_message_subject_header $subject", $mail_content, $headers);
 
 	// Save the values in SQL and process the paynow buttons
 	$q = "INSERT INTO $pro_mysql_pending_renewal_table (id,adm_login,renew_date,renew_time,product_id,renew_id,heb_type,country_code)
