@@ -1,9 +1,132 @@
 <?php
 
-function domainNamePopup($domain_name=""){
-	$out = "";
+// If the admin has en_US.UTF-8, and filename is registration_msg/vps_open,
+// then the function will try to open, in order:
+// * /etc/dtc/registration_msg/vps_open_en_US.UTF-8.txt
+// * /etc/dtc/registration_msg/vps_open_en_US.txt
+// * /etc/dtc/registration_msg/vps_open_en.txt
+// * /etc/dtc/registration_msg/vps_open.txt
+// which ever is found first...
+// Then this is repeated with other folders:
+// /usr/local/www/dtc/etc/ and /usr/share/dtc/etc/
+function readCustomizedMessage($filename,$adm_login){
+	$mylang = findLastUsedLangByUser($adm_login);
 
-	$allTLD = array(".com", ".aero", ".asia", ".biz", ".cat", ".coop", ".edu", ".gov", ".info", ".int", ".jobs", ".mil", ".mobi", ".museum", ".name", ".net",".org", ".pro", ".tel", ".travel",
+	// 1st try /etc/dtc/filename_en_US.UTF-8.txt
+	if( file_exists( "/etc/dtc/" . $filename . "_" . $mylang . ".txt" ) ){
+		$to_open = "/etc/dtc/" . $filename . $mylang . ".txt";
+	// Then /etc/dtc/filename_en_US.txt
+	}else if( file_exists( "/etc/dtc/" . $filename . "_" . substr($mylang,0,5) . ".txt" ) ){
+		$to_open = "/etc/dtc/" . $filename . "_" . substr($mylang,0,5) . ".txt";
+	// Then /etc/dtc/filename_en.txt
+	}else if( file_exists( "/etc/dtc/" . $filename . "_" . substr($mylang,0,2) . ".txt" ) ){
+		$to_open = "/etc/dtc/" . $filename . "_" . substr($mylang,0,2) . ".txt";
+	// then /etc/dtc/filename.txt
+	}else if( file_exists( "/etc/dtc/" . $filename . ".txt" ) ){
+		$to_open = "/etc/dtc/" . $filename . ".txt";
+	// then /usr/local/www/dtc/etc/filename_en_US.UTF-8.txt
+	}else if( file_exists( "/usr/local/www/dtc/etc/" . $filename . "_" . $mylang . ".txt" ) ){
+		$to_open = "/usr/local/www/dtc/etc/" . $filename . "_" . $mylang . ".txt";
+	// then /usr/local/www/dtc/etc/filename_en_US.txt
+	}else if( file_exists( "/usr/local/www/dtc/etc/" . $filename . "_" . substr($mylang,0,5) . ".txt" ) ){
+		$to_open = "/usr/local/www/dtc/etc/" . $filename . "_" . substr($mylang,0,5) . ".txt";
+	// then /usr/local/www/dtc/etc/filename_en.txt
+	}else if( file_exists( "/usr/local/www/dtc/etc/" . $filename . "_" . substr($mylang,0,2) . ".txt" ) ){
+		$to_open = "/usr/local/www/dtc/etc/" . $filename . "_" . substr($mylang,0,2) . ".txt";
+	// then /usr/local/www/dtc/etc/filename.txt
+	}else if( file_exists( "/usr/local/www/dtc/etc/" . $filename . ".txt" ) ){
+		$to_open = "/usr/local/www/dtc/etc/" . $filename . ".txt";
+	// then /usr/share/dtc/etc/filename_en_US.UTF-8.txt
+	}else if( file_exists( "/usr/share/dtc/etc/" . $filename . "_" . $mylang . ".txt" ) ){
+		$to_open = "/usr/share/dtc/etc/" . $filename . "_" . $mylang . ".txt";
+	// then /usr/share/dtc/etc/filename_en_US.txt
+	}else if( file_exists( "/usr/share/dtc/etc/" . $filename . "_" . substr($mylang,0,5) . ".txt" ) ){
+		$to_open = "/usr/share/dtc/etc/" . $filename . "_" . substr($mylang,0,5) . ".txt";
+	// then /usr/share/dtc/etc/filename_en.txt
+	}else if( file_exists( "/usr/share/dtc/etc/" . $filename . "_" . substr($mylang,0,2) . ".txt" ) ){
+		$to_open = "/usr/share/dtc/etc/" . $filename . "_" . substr($mylang,0,2) . ".txt";
+	// then /usr/share/dtc/etc/filename.txt
+	}else if( file_exists( "/usr/share/dtc/etc/" . $filename . ".txt" ) ){
+		$to_open = "/usr/share/dtc/etc/" . $filename . ".txt";
+	// then it means we didn't find the file...
+	}else{
+		return "Customized message language file not found. Get in touch with your administrator.";
+	}
+	$fp = fopen($to_open, "r");
+	$content = fread($fp,filesize($to_open));
+	fclose($fp);
+	return $content;
+}
+
+// Create a random hash, making sure that it doesn't exists in the DB already
+function createSupportHash(){
+	global $pro_mysql_tik_queries_table;
+	$n = 1;
+	while($n != 0){
+		$hash = getRandomValue();
+		$q = "SELECT id FROM $pro_mysql_tik_queries_table WHERE hash='$hash';";
+		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+	}
+	return $hash;
+}
+
+// Returns 0 if not found, a valid ID otherwise
+function findLastTicketID($hash){
+	global $pro_mysql_tik_queries_table;
+
+	$q = "SELECT id,reply_id FROM $pro_mysql_tik_queries_table WHERE hash='$hash';";
+	$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n != 1){
+		return 0;
+	}
+	$a = mysql_fetch_array($r);
+	if( $a["reply_id"] == 0){
+		return $a["id"];
+	}
+	$i = 100;
+	while($a["reply_id"] != 0 && $i-- != 0){
+		$q = "SELECT id,reply_id FROM $pro_mysql_tik_queries_table WHERE id='".$a["reply_id"]."';";
+		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n != 1){
+			return 0;
+		}
+		$a = mysql_fetch_array($r);
+	}
+	return $a["id"];
+}
+
+function getCustomizableMessage($file_name){
+	if(file_exists("/etc/dtc/$file_name")){
+		$fname = "/etc/dtc/$file_name";
+	}else if(file_exists("/usr/local/www/dtc/etc/$file_name")){
+		$fname = "/usr/local/www/dtc/etc/$file_name";
+	}else{
+		$fname = "/usr/share/dtc/etc/$file_name";
+	}
+	if(file_exists($fname)){
+		$fp = fopen($fname,"r");
+		if($fp != NULL){
+			$out = fread($fp,filesize($fname));
+			fclose($fp);
+		}else{
+			$out = "";
+		}
+	}else{
+		$out = "";
+	}
+	return $out;
+}
+
+function headAndTailEmailMessage($msg){
+	$msg = getCustomizableMessage("messages_header.txt") . $msg;
+	$signature = getCustomizableMessage("signature.txt");
+	return str_replace("%%%SIGNATURE%%%",$signature,$msg);
+}
+
+$allTLD = array(".com", ".aero", ".asia", ".biz", ".cat", ".coop", ".edu", ".gov", ".info", ".int", ".jobs", ".mil", ".mobi", ".museum", ".name", ".net",".org", ".pro", ".tel", ".travel",
 ".ac",".ad",".ae",".af",".ag",".ai",".al",".am",".an",".ao",".aq",".ar",".as",".at",".au",".aw",".ax",".az",
 ".ba",".bb",".bd",".be",".bf",".bg",".bh",".bi",".bj",".bm",".bn",".bo",".br",".bs",".bt",".bw",".by",".bz",
 ".ca",".cc",".cd",".cf",".cg",".ch",".ci",".ck",".cl",".cm",".cn",".co",".cr",".cu",".cv",".cx",".cy",".cz",
@@ -28,17 +151,26 @@ function domainNamePopup($domain_name=""){
 ".va",".vc",".ve",".vg",".vi",".vn",".vu",
 ".wf",".ws",
 ".ye",".yt",".yu",
-".za",".zm",".zw");
+".ac.za",".city.za",".co.za",".edu.za",".gov.za",".law.za",".mil.za",".nom.za",".org.za",".school.za",".zm",".zw");
+
+function isTLD($tld){
+	global $allTLD;
+	return in_array ($tld, $allTLD);
+}
+
+function domainNamePopup($domain_name=""){
+	global $allTLD;
+
+	$out = "";
 
-	$keys = array_keys($allTLD);
 	$nbr_tld = sizeof($allTLD);
 	for($i=0;$i<$nbr_tld;$i++){
-		if( ereg("\\".$keys[$i]."\$",$domain_name)){
+		if( ereg("\\".$allTLD[$i]."\$",$domain_name)){
 			$selected = " selected ";
 		}else{
 			$selected = "";
 		}
-		$out .= "<option value=\"".$keys[$i]."\" $selected>". $keys[$i] ."</option>";
+		$out .= "<option value=\"".$allTLD[$i]."\" $selected>". $allTLD[$i] ."</option>";
 	}
 	return $out;
 }
@@ -85,7 +217,8 @@ function findLastUsedLangByUser($adm_login){
 			$a = mysql_fetch_array($r);
 			return $a["last_used_lang"];
 		}else{
-			return false;
+			// Fallback to default english...
+			return "en_US.UTF-8";
 		}
 	}
 }
@@ -119,7 +252,7 @@ function mdpauto(){
 	//This pools grant no mistake between 0, o or O for example...
 	$pool = "abcdefghjkmnprstwxyz234589";
 	$sid = "";
-	for($index=0;$index<8;$index++){
+	for($index=0;$index<12;$index++){
 		$sid .= substr($pool,(rand()%(strlen($pool))),1);
 	}
 	return $sid;
@@ -138,9 +271,18 @@ function autoGeneratePassButton($form_name,$field_name){
 function dtc_gen_passwd(frm_name,fld_name){
 	document[frm_name][fld_name].value = '".$mdp."';
 	document[frm_name][fld_name].type = 'text';
+//	dtc_see_password(frm_name,fld_name);
 }
 function dtc_see_password(frm_name,fld_name){
 	document[frm_name][fld_name].type = 'text';
+//	var curObj = document[frm_name][fld_name];
+//	if (curObj.getAttribute('type') != 'text') {
+//		var newObj=document.createElement('input');
+//		newObj.setAttribute('type','text');
+//		newObj.setAttribute('name',curObj.getAttribute('name'));
+//		newObj.setAttribute('value',curObj.getAttribute('value'));
+//		curObj.parentNode.replaceChild( newObj, curObj );
+//	}
 }
 </script>";
 	}
@@ -197,6 +339,44 @@ function HTTP_Post($URL,$data, $referrer=""){
 	return $result;
 }
 
+function HTTP_Get($URL,$data, $referrer=""){
+	$result = "";
+	// parsing the given URL
+	$URL_Info=parse_url($URL);
+
+	// Building referrer
+	if($referrer=="") // if not given use this script as referrer
+		$referrer=$_SERVER["SCRIPT_URI"];
+
+	// making string from $data
+	if (strlen($data)) {
+		foreach($data as $key=>$value)
+			$values[]="$key=".urlencode($value);
+		$data_string=implode("&",$values);
+	} else
+		$data_string='';
+
+	// Find out which port is needed - if not given use standard (=80)
+	if(!isset($URL_Info["port"]))
+		$URL_Info["port"]=80;
+
+	// building POST-request:
+	$request = "";
+	$request.="GET ".$URL_Info["path"]."?".$data_string." HTTP/1.1\n";
+	$request.="Host: ".$URL_Info["host"]."\n";
+	$request.="Referer: $referrer\n";
+	$request.="Connection: close\n";
+	$request.="\n\n";
+
+	$fp = fsockopen($URL_Info["host"],$URL_Info["port"]);
+	fputs($fp, $request);
+	while(!feof($fp)){
+		$result .= fgets($fp, 128);
+	}
+	fclose($fp);
+	return $result;
+}
+
 function logPay($txt){
 //	$fp = fopen("/tmp/paylog.txt","a");
 //	fwrite($fp,$txt."\n");
@@ -234,6 +414,7 @@ function checkLoginPassAndDomain($adm_login,$adm_pass,$domain_name){
 	global $pro_mysql_admin_table;
 	global $pro_mysql_domain_table;
 	global $pro_mysql_config_table;
+	global $pro_mysql_tik_admins_table;
 
 	if(strlen($adm_pass) > 16){
 	}
@@ -242,7 +423,7 @@ function checkLoginPassAndDomain($adm_login,$adm_pass,$domain_name){
 	$result = mysql_query($query)or die("Cannot execute query \"$query\" !!!".mysql_error());
 	$num_rows = mysql_num_rows($result);
 	if($num_rows != 1){
-		$query = "SELECT * FROM $pro_mysql_config_table WHERE root_admin_random_pass='$adm_pass' AND pass_expire > '".mktime()."';";
+		$query = "SELECT * FROM $pro_mysql_tik_admins_table WHERE pass_next_req='$adm_pass' AND pass_expire > '".mktime()."';";
 		$result = mysql_query($query)or die("Cannot execute query \"$query\" !".mysql_error());
 		$num_rows = mysql_num_rows($result);
 		if($num_rows != 1){
@@ -265,12 +446,13 @@ function checkLoginPassAndDomain($adm_login,$adm_pass,$domain_name){
 function checkLoginPass($adm_login,$adm_pass){
 	global $pro_mysql_admin_table;
 	global $pro_mysql_config_table;
+	global $pro_mysql_tik_admins_table;
 
 	$query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login' AND (adm_pass='$adm_pass' OR (pass_next_req='$adm_pass' AND pass_expire > '".mktime()."'));";
 	$result = mysql_query($query)or die("Cannot execute query \"$query\" !!!".mysql_error());
 	$num_rows = mysql_num_rows($result);
 	if($num_rows != 1){
-		$query = "SELECT * FROM $pro_mysql_config_table WHERE root_admin_random_pass='$adm_pass' AND pass_expire > '".mktime()."';";
+		$query = "SELECT * FROM $pro_mysql_tik_admins_table WHERE pass_next_req='$adm_pass' AND pass_expire > '".mktime()."';";
 		$result = mysql_query($query)or die("Cannot execute query \"$query\" !".mysql_error());
 		$num_rows = mysql_num_rows($result);
 		if($num_rows != 1){
@@ -298,12 +480,18 @@ function isIP($ip){
 	else			return true;
 }
 
+function isDTCLogin($login){
+	$reg = "^([a-zA-Z0-9]+)([._a-zA-Z0-9-]+)\$";
+	if(!ereg($reg,$login))	return false;
+	else			return true;
+}
+
 // The subdomain string allowed to be hosted by DTC
 function checkSubdomainFormat($name){
 	if($name == ""){
 		return false;
 	}
-	if(ereg("^([a-z0-9\_]+)([.a-z0-9\_-]*)([.a-z0-9]+)\$",$name))
+	if(ereg("^([a-z0-9]+)([.a-z0-9-]*)([.a-z0-9]+)\$",$name))
 		return true;
 	else{
 		if(ereg("^([a-z0-9])\$",$name))
@@ -325,14 +513,14 @@ function isSSHKey($ssh_key){
 
 // Check for email addr we allow to create using DTC
 function isMailbox($mailbox){
-	$reg = "^([a-zA-Z0-9])|([a-zA-Z0-9]+)([_.a-zA-Z0-9-]+)\$";
+	$reg = "^([a-z0-9])|([a-z0-9]+)([._a-z0-9-]+)\$";
 	if(!ereg($reg,$mailbox))	return false;
 	else			return true;
 }
 
 // Check for valid (but maybe non-RFC) email addr we allow forwarding to
 function isValidEmail($email){
-	$reg = "^([a-z0-9]+)([_.a-z0-9-]*)@([a-z0-9]+)([-a-z0-9.]*)\.([a-z0-9-]*)([a-z0-9]+)\$";
+	$reg = "^([a-zA-Z0-9])|([a-zA-Z0-9]+)([._a-zA-Z0-9-]*)@([a-z0-9]+)([-a-z0-9.]*)\.([a-z0-9-]*)([a-z0-9]+)\$";
 	if(!ereg($reg,$email))	return false;
 	else			return true;
 }
@@ -354,7 +542,7 @@ function isHostname($hostname){
 // Check for email addr we allow to create using DTC
 function isFtpLogin($mailbox){
 	if(isValidEmail($mailbox))	return true;
-	$reg = "^([a-zA-Z0-9]+)([.a-zA-Z0-9-]+)\$";
+	$reg = "^([a-zA-Z0-9]+)([._a-zA-Z0-9-]+)\$";
 	if(!ereg($reg,$mailbox))	return false;
 	else			return true;
 }
@@ -495,7 +683,7 @@ function make_new_adm_domain_dir($path){
 
 	if(!file_exists("$path/subdomains/www/logs")){
 		mkdir("$path/subdomains/www/logs", 0750);
-		$console .= "mkdir $path/mailbox;<br>";
+		$console .= "mkdir $path/subdomains/www/logs;<br>";
 	}
 	umask($oldumask);
 }
@@ -563,7 +751,7 @@ function resubscribe_VPS_server_list_users($list_name){
 		unlink($file_list[$i]);
 	}
 
-	$q = "SELECT $pro_mysql_client_table.email
+	$q = "SELECT DISTINCT $pro_mysql_client_table.email
 	FROM $pro_mysql_vps_server_lists_table,$pro_mysql_vps_table,$pro_mysql_admin_table,$pro_mysql_client_table
 	WHERE $pro_mysql_vps_server_lists_table.list_name = '$list_name'
 	AND $pro_mysql_vps_server_lists_table.hostname = $pro_mysql_vps_table.vps_server_hostname
@@ -626,7 +814,7 @@ function addVPSToUser($adm_login,$vps_server_hostname,$product_id,$operating_sys
 		 die("Cannot find available IP and Xen name in $vps_server_hostname line ".__LINE__." file ".__FILE__);
 	}
 	$vps_ip = mysql_fetch_array($r);
-	$q = "UPDATE $pro_mysql_vps_ip_table SET available='no' WHERE ip_addr='".$vps_ip["ip_addr"]."';";
+	$q = "UPDATE $pro_mysql_vps_ip_table SET available='no' WHERE vps_xen_name='".$vps_ip["vps_xen_name"]."' AND vps_server_hostname='".$vps_ip["vps_server_hostname"]."';";
 	$r = mysql_query($q)or die("Cannot query : \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 
 	$exp_date = calculateExpirationDate(date("Y-m-d"),$product["period"]);
@@ -634,6 +822,8 @@ function addVPSToUser($adm_login,$vps_server_hostname,$product_id,$operating_sys
 	VALUES('','$adm_login','".$vps_ip["vps_server_hostname"]."','".$vps_ip["vps_xen_name"]."','".date("Y-m-d")."','$exp_date','".$product["quota_disk"]."','".$product["memory_size"]."','$product_id','".$product["bandwidth"]."','$operating_system');";
 	$r = mysql_query($q)or die("Cannot query : \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 
+	updateUsingCron("gen_named='yes',reload_named ='yes'");
+
 	// Subscribe user to the lists of the VPS
 	VPS_Server_Subscribe_To_Lists($vps_server_hostname);
 
@@ -656,13 +846,10 @@ function addDomainToUser($adm_login,$adm_pass,$domain_name,$domain_password=""){
 
 	global $conf_root_admin_random_pass;
 	global $conf_pass_expire;
+	global $conf_unix_type;
 
-	if($conf_root_admin_random_pass == $adm_pass &&  $conf_pass_expire > mktime()){
-		$query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login';";
-	}else{
-		$query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login' AND (adm_pass='$adm_pass' OR (pass_next_req='$adm_pass' AND pass_expire > '".mktime()."'));";
-	}
-
+	checkLoginPass($adm_login,$adm_pass);
+	$query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login';";
 	$result = mysql_query($query)or die("Cannot query : \"$query\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 	$numrows = mysql_num_rows($result);
 	if($numrows != 1){
@@ -679,34 +866,30 @@ function addDomainToUser($adm_login,$adm_pass,$domain_name,$domain_password=""){
 		}
 
 		make_new_adm_domain_dir("$admin_path/$domain_name");
+		if ($conf_unix_type == "bsd") {			// no -u in freebsd, blows away custom changes, NEEDFIX: KC
+			exec("cp -flpRv $conf_chroot_path/* $admin_path/$domain_name/subdomains/www");
+			createSymLink("subdomains/www/libexec", "$admin_path/$domain_name/libexec");	// also symlink libexec for fbsd while we're here: KC
+			createSymLink("$domain_name/subdomains/www/libexec", "$admin_path/libexec");
+		}else{
+			exec("cp -fulpRv $conf_chroot_path/* $admin_path/$domain_name/subdomains/www");
+		}
 		exec("cp -fulpRv $conf_chroot_path/* $admin_path/$domain_name/subdomains/www");
 		// create a link so that the user can log in via SSH to $admin_path or $admin_path/$domain_name
-		exec("if [ ! -e $admin_path/$domain_name/bin ]; then ln -s subdomains/www/bin  $admin_path/$domain_name/bin; fi");
-		exec("if [ ! -e $admin_path/$domain_name/var ]; then ln -s subdomains/www/var  $admin_path/$domain_name/var; fi");
-		exec("if [ ! -e $admin_path/$domain_name/lib ]; then ln -s subdomains/www/lib  $admin_path/$domain_name/lib; fi");
-		exec("if [ ! -e $admin_path/$domain_name/lib64 ]; then ln -s subdomains/www/lib  $admin_path/$domain_name/lib64; fi");
-		exec("if [ ! -e $admin_path/$domain_name/sbin ]; then ln -s subdomains/www/sbin  $admin_path/$domain_name/sbin; fi");
-		exec("if [ ! -e $admin_path/$domain_name/tmp ]; then ln -s subdomains/www/tmp  $admin_path/$domain_name/tmp; fi");
-		exec("if [ ! -e $admin_path/$domain_name/usr ]; then ln -s subdomains/www/usr  $admin_path/$domain_name/usr; fi");
-		exec("if [ ! -e $admin_path/$domain_name/dev ]; then ln -s subdomains/www/dev  $admin_path/$domain_name/dev; fi");
-		exec("if [ ! -e $admin_path/$domain_name/etc ]; then ln -s subdomains/www/etc  $admin_path/$domain_name/etc; fi");
-
-		exec("if [ `uname -m` = \"x86_64\" ] ; then if [ ! -e $admin_path/$domain_name/lib64 ] ; then ln -s subdomains/www/lib $admin_path/$domain_name/lib64 ; fi ; fi");
-
-		// now for the admin user chroot links
-		exec("if [ ! -e $admin_path/bin ]; then ln -s $domain_name/subdomains/www/bin  $admin_path/bin; fi");
-		exec("if [ ! -e $admin_path/var ]; then ln -s $domain_name/subdomains/www/var  $admin_path/var; fi");
-		exec("if [ ! -e $admin_path/lib ]; then ln -s $domain_name/subdomains/www/lib  $admin_path/lib; fi");
-		exec("if [ ! -e $admin_path/lib64 ]; then ln -s $domain_name/subdomains/www/lib  $admin_path/lib64; fi");
-		exec("if [ ! -e $admin_path/sbin ]; then ln -s $domain_name/subdomains/www/sbin  $admin_path/sbin; fi");
-		exec("if [ ! -e $admin_path/tmp ]; then ln -s $domain_name/subdomains/www/tmp  $admin_path/tmp; fi");
-		exec("if [ ! -e $admin_path/usr ]; then ln -s $domain_name/subdomains/www/usr  $admin_path/usr; fi");
-		exec("if [ ! -e $admin_path/dev ]; then ln -s $domain_name/subdomains/www/dev  $admin_path/dev; fi");
-		exec("if [ ! -e $admin_path/etc ]; then ln -s $domain_name/subdomains/www/etc  $admin_path/etc; fi");
-
-		exec("if [ `uname -m` = \"x86_64\" ] ; then if [ ! -e $admin_path/lib64 ] ; then ln -s subdomains/www/lib $admin_path/lib64 ; fi ; fi");
-
-		system ("cp -rup $conf_generated_file_path/template/* $admin_path/$domain_name/subdomains/www/html");
+		// typo renamed to foreach *steveetm*
+		foreach ( explode( " " , "bin var lib lib64 sbin tmp usr dev etc" ) as $subdir) {
+			createSymLink("subdomains/www/$subdir", "$admin_path/$domain_name/$subdir");
+			createSymLink("$domain_name/subdomains/www/$subdir", "$admin_path/$subdir");
+		}
+		
+		if ($conf_unix_type == "bsd") {			// no -u in freebsd, could blow away custom changes, NEEDFIX: KC
+			$cp_opt = "p";
+		}else{
+			$cp_opt = "up";
+		}
+		system ("cp -r$cp_opt $conf_generated_file_path/template/* $admin_path/$domain_name/subdomains/www/html");
+		if( file_exists("$conf_generated_file_path/template/.htaccess") ){
+			system ("cp -$cp_opt $conf_generated_file_path/template/.htaccess $admin_path/$domain_name/subdomains/www/html");
+		}
 	}
 
 	// Create domain in database
@@ -829,4 +1012,29 @@ function dtc_makesalt()  {
 	return '$1$'.$hash.'$';
 }
 
+function createSymLink($target, $link) {
+	global $console;
+
+	if(is_link("$link")) {
+		if(!file_exists($link)) { // if this is a link and it points to a non-existing file
+			$console.="<br/ >$link points to a non-existing file. Fixing that<br />";
+			if(unlink($link)) {
+				if(!symlink($target,$link)) {
+					$console.="<br/ >WARNING: error encountered while trying to create $link<br />";
+				}
+				else {
+					$console.="$link now points to $target<br />";
+				}
+			}
+			else {
+				$console.="<br/ >WARNING: error encountered while trying to delete $link<br />";
+			}
+		}
+	} else {
+		if(!file_exists($link)) {
+			symlink($target,$link);
+		}
+	}
+}
+
 ?>
