@@ -35,7 +35,11 @@ require("$dtcshared_path/inc/fetchmail.php");
 
 // The soap API to connect to xen servers
 if (!class_exists("nusoapclient")){
-	require_once("$dtcshared_path/inc/nusoap.php");
+	if( file_exists("/usr/share/php/nusoap/nusoap.php")){
+		require_once("/usr/share/php/nusoap/nusoap.php");
+	}else{
+		require_once("$dtcshared_path/inc/nusoap.php");
+	}
 }
 
 // The maxmind API
@@ -45,7 +49,7 @@ require("$dtcshared_path/maxmind/CreditCardFraudDetection.php");
 /////////////////////////////////////////
 // The secure paiement buttons and api //
 /////////////////////////////////////////
-require("$dtcshared_path/securepay/paiement.php");			// The draw paiement button function
+require("$dtcshared_path/securepay/pay_functions.php");			// The draw paiement button functions and modules
 
 //////////////////////////
 // Domain import/export //
