@@ -444,6 +444,7 @@ function skin_LayoutAdminPage (){
 	global $adm_pass;
 	global $conf_session_expir_minute;
 	global $pro_mysql_config_table;
+	global $pro_mysql_tik_admins_table;
 	global $conf_skin;
 
 	global $top_commands;
@@ -500,7 +501,7 @@ function skin_LayoutAdminPage (){
 		break;
 	case "generate": // Gen Config Files
 		$mainFrameCells[] = skin($conf_skin,$top_commands, _("Launching the configuration files generation") );
-		$the_iframe = "<br><IFRAME src=\"deamons_state.php\" width=\"100%\" height=\"135\"></iframe>";
+		$the_iframe = "<br><br>"._("Please note that you need to create at least one email and one FTP account in order to have the daemon status working!")."<br><IFRAME src=\"deamons_state.php\" width=\"100%\" height=\"135\"></iframe>";
 		$mainFrameCells[] = skin($conf_skin,$the_iframe, _("Deamons states") ); // fixed bug by seeb
 		// The console
 		$mainFrameCells[] = skinConsole();
@@ -542,8 +543,9 @@ function skin_LayoutAdminPage (){
 			$rand = $adm_random_pass;
 		}else{
 			$rand = getRandomValue();
+			$adm_random_pass = $rand;
 			$expirationTIME = mktime() + (60 * $conf_session_expir_minute);
-			$q = "UPDATE $pro_mysql_config_table SET root_admin_random_pass='$rand', pass_expire='$expirationTIME';";
+			$q = "UPDATE $pro_mysql_tik_admins_table SET pass_next_req='$rand', pass_expire='$expirationTIME' WHERE pseudo='".$_SERVER["PHP_AUTH_USER"]."';";
 			$r = mysql_query($q)or die("Cannot execute query \"$q\" !");
 		}
 		$skinedConsole = '<table cellpadding="0" cellspacing="0" class="console">
@@ -564,7 +566,7 @@ function skin_LayoutAdminPage (){
     </td>
     <td class="box_wnb_content" valign="top">
       <div class="box_wnb_content_container">
-      <h2>'. _("User administration") .'</h2>
+      <h2>'. _("User administration") ." $adm_login".'</h2>
       '.$bwoup_user_edit
       .$skinedConsole.'
       </div>
