@@ -12,9 +12,11 @@ function drawAdminTools_Dedicated($admin,$dedicated_server_hostname){
 
 	global $secpayconf_currency_letters;
 
+	global $submit_err;
+
 	get_secpay_conf();
 
-	$out = "";
+	$out = "<font color=\"red\">$submit_err</font>";
 
 	// Check owner and fetch!
 	checkDedicatedAdmin($adm_login,$adm_pass,$dedicated_server_hostname);
@@ -67,17 +69,38 @@ function drawAdminTools_Dedicated($admin,$dedicated_server_hostname){
 
 //	$out .= "Dedicated server content!";
 	$out .= "<br><br><h3>"._("IP addresses: ")."</h3>";
+	$frm_start = "<form action=\"?\">
+<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
+<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
+<input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">";
 
 	$q = "SELECT * FROM $pro_mysql_dedicated_ips_table WHERE dedicated_server_hostname='$dedicated_server_hostname'";
 	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
+
+	$out .= dtcFormTableAttrs();
+
 	for($i=0;$i<$n;$i++){
 		$a = mysql_fetch_array($r);
-		if($i > 0){
+		if($i % 2){
+			$alt_color = 0;
+		}else{
+			$alt_color = 1;
+		}
+		$out .= dtcFormLineDraw($a["ip_addr"],"$frm_start<input type=\"hidden\" name=\"action\" value=\"set_dedicated_ip_rdns\">
+<input type=\"hidden\" name=\"ip_addr\" value=\"".$a["ip_addr"]."\">
+<input type=\"text\" name=\"rdns\" value=\"".$a["rdns_addr"]."\">
+</td><td><div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\" onMouseOut=\"this.className='input_btn_container';\">
+<div class=\"input_btn_left\"></div>
+<div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" value=\""._("Change RDNS")."\"></div>
+<div class=\"input_btn_right\"></div>
+</div></form>",$alt_color);
+/*		if($i > 0){
 			$out .= ", ";
 		}
-		$out .= $a["ip_addr"];
+		$out .= $a["ip_addr"];*/
 	}
+	$out .= "</table>";
 	return $out;
 }
 
