@@ -1,12 +1,77 @@
 <?php
 
+function fetchmailAccountsCreateCallback($id){
+	updateUsingCron("gen_fetchmail='yes'");
+}
+function fetchmailAccountsDeleteCallback($id){
+	updateUsingCron("gen_fetchmail='yes'");
+}
+function fetchmailAccountsEditCallback($id){
+	updateUsingCron("gen_fetchmail='yes'");
+}
 function drawImportedMail($mailbox){
 	global $adm_email_login;
 	global $adm_email_pass;
 	global $errTxt;
 	global $pro_mysql_fetchmail_table;
 
+	$mydomain = $mailbox["data"]["mbox_host"];
+	$myuserid = $mailbox["data"]["id"];
+
 	$out = "";
+	$dsc = array(
+		"title" => _("List of your fetchmail imported accounts:") ,
+		"new_item_title" => _("New fetchmail address") ,
+		"new_item_link" => _("new fetchmail address") ,
+		"edit_item_title" => _("Fetchmail configuration:") ,
+		"table_name" => $pro_mysql_fetchmail_table,
+		"action" => "fetchmail_table_editor",
+		"forward" => array("adm_email_login","adm_email_pass","addrlink"),
+		"id_fld" => "id",
+		"list_fld_show" => "pop3_email",
+		"max_item" => 3,
+		"num_item_txt" => _("Number of active fetchmail imported email:") ,
+		"where_list" => array(
+			"domain_name" => $mydomain,
+			"domain_user" => $myuserid),
+		"check_unique" => array( "pop3_email" ),
+		"check_unique_msg" => _("There is already a mailbox by that name") ,
+		"order_by" => "pop3_email",
+		"create_item_callback" => "fetchmailAccountsCreateCallback",
+		"delete_item_callback" => "fetchmailAccountsDeleteCallback",
+		"edit_item_callback" => "fetchmailAccountsEditCallback",
+		"cols" => array(
+			"id" => array(
+				"type" => "id",
+				"display" => "no",
+				"legend" => _("Login:") ),
+			"pop3_email" => array(
+				"type" => "text",
+				"check" => "email",
+				"legend" => _("Email to fetch:") ),
+			"pop3_server" => array (
+				"type" => "text",
+				"check" => "subdomain_or_ip",
+				"legend" => _("Mail server to import from:") ),
+			"pop3_login" => array(
+				"type" => "text",
+				"check" => "dtc_login_or_email",
+				"legend" => _("Login:") ),
+			"pop3_pass" => array(
+				"type" => "password",
+				"legend" => _("Password:") ),
+			"checkit" => array(
+				"type" => "checkbox",
+				"values" => array( "yes","no"),
+				"default" => "no",
+				"legend" => _("Use it:") ),
+			)
+		);
+        $out = dtcListItemsEdit($dsc);
+	return $out;
+
+
+/*	$out = "";
 
 	if(isset($errTxt) && $errTxt != ""){
 		$out .= "<font color=\"red\">$errTxt</font><br>";
@@ -88,6 +153,8 @@ function drawImportedMail($mailbox){
 	$out .= "</table>";
 
 	return $out;
+*/
+
 }
 
 function drawAntispamRules($mailbox){
@@ -277,7 +344,7 @@ function drawAdminTools_emailAccount($mailbox){
 	$out = "<table width=\"100%\" heigh=\"1\">
 <tr>
 	<td width=\"50%\" valign=\"top\">".$left."</td>
-	<td width=\"4\" background=\"gfx/skin/frame/border_2.gif\"></td>
+	<td width=\"4\" background=\"gfx/border_2.gif\"></td>
 	<td valign=\"top\">".$right."</td>
 </tr>
 </table>
@@ -430,7 +497,9 @@ function emailAccountsCreateCallback ($id){
 		return "<font color=\"red\">". _("Error: Email group alias already exists with this name!") ."</font><br />";
 	}
 	$crypted_pass = crypt($a["passwd"], dtc_makesalt());
-	writeDotQmailFile($a["id"],$a["mbox_host"]);
+	if (!$cyrus_used){
+		writeDotQmailFile($a["id"],$a["mbox_host"]);
+	}
 	$admin_path = getAdminPath($adm_login);
 	$box_path = "$admin_path/$edit_domain/Mailboxs/".$a["id"];
 	$q = "UPDATE $pro_mysql_pop_table SET crypt='$crypted_pass',home='$box_path',uid='$conf_dtc_system_uid',gid='$conf_dtc_system_gid',fullemail='".$a["id"].'@'.$a["mbox_host"]."',quota_couriermaildrop=CONCAT(1024000*quota_size,'S,',quota_files,'C') WHERE autoinc='$id';";
@@ -467,7 +536,9 @@ function emailAccountsEditCallback ($id){
 	$q = "UPDATE $pro_mysql_pop_table SET crypt='$crypted_pass',quota_couriermaildrop=CONCAT(1024000*quota_size,'S,',quota_files,'C') WHERE autoinc='$id';";
 	$r = mysql_query($q)or die ("Cannot query $q line: ".__LINE__." file ".__FILE__." sql said:" .mysql_error());
 
-	writeDotQmailFile($a["id"],$a["mbox_host"]);
+	if(!$cyrus_used){
+		writeDotQmailFile($a["id"],$a["mbox_host"]);
+	}
 	updateUsingCron("gen_qmail='yes', qmail_newu='yes'");
 
 	if ($cyrus_used){
@@ -488,25 +559,31 @@ function emailAccountsEditCallback ($id){
 function emailAccountsDeleteCallback ($id){
 	global $cyrus_used;
 	global $pro_mysql_pop_table;
+	global $pro_mysql_fetchmail_table;
 
 	triggerMXListUpdate();
 	updateUsingCron("gen_qmail='yes', qmail_newu='yes'");
+	$q = "SELECT id, mbox_host, home FROM $pro_mysql_pop_table WHERE autoinc='$id';";
+	$r = mysql_query($q)or die ("Cannot query $q line: ".__LINE__." file ".__FILE__." sql said:" .mysql_error());
+	$n = mysql_num_rows($r);
+	if($n != 1){
+		die("Cannot find created email line ".__LINE__." file ".__FILE__);
+	}
+	$v = mysql_fetch_array($r);
 	if ($cyrus_used){
 		# login to cyradm
-		$q = "SELECT id, mbox_host FROM $pro_mysql_pop_table WHERE autoinc='$id';";
-		$r = mysql_query($q)or die ("Cannot query $q line: ".__LINE__." file ".__FILE__." sql said:" .mysql_error());
-		$n = mysql_num_rows($r);
-		if($n != 1){
-			die("Cannot find created email line ".__LINE__." file ".__FILE__);
-		}
-                $v = mysql_fetch_row($r);
 		$cyr_conn = new cyradm;
 		$error=$cyr_conn -> imap_login();
 		if ($error!=0){
 			die ("imap_login Error $error");
 		}
-		$result=$cyr_conn->deletemb("user/" . $v[0]."@".$v[1]);
+		$result=$cyr_conn->deletemb("user/" . $v["id"]."@".$v["mbox_host"]);
 	}
+	$cmd = "rm -rf " . $v["home"];
+	exec($cmd,$exec_out,$return_val);
+	$q = "DELETE FROM $pro_mysql_fetchmail_table WHERE domain_user='".$v["id"]."' AND domain_name='".$v["mbox_host"]."';";
+	$r = mysql_query($q)or die ("Cannot query $q line: ".__LINE__." file ".__FILE__." sql said:" .mysql_error());
+	updateUsingCron("qmail_newu='yes',restart_qmail='yes',gen_qmail='yes'");
 	return "";
 }
 function drawAdminTools_Emails($domain){
@@ -559,6 +636,7 @@ function drawAdminTools_Emails($domain){
 				"legend" => _("Login:") ),
 			"memo" => array (
 				"type" => "text",
+				"help" => _("This text is just a memo for yourself, and will not really be used."),
 				"legend" => _("Name:") ),
 			"passwd" => array(
 				"type" => "password",
@@ -566,10 +644,12 @@ function drawAdminTools_Emails($domain){
 				"legend" => _("Password:") ),
 			"spam_mailbox_enable" => array(
 				"type" => "checkbox",
+				"help" => _("If selected, spams will be sent in a SPAM folder and wont reach your inbox. Later you can check this folder with the webmail or using IMAP."),
 				"values" => array( "yes","no"),
 				"legend" => _("Enable SPAM filtering: ") ),
 			"spam_mailbox" => array(
 				"type" => "text",
+				"help" => _("Name of the SPAM folder to receive the spam (the above option has to be activated)."),
 				"default" => "SPAM",
 				"legend" => _("SPAM mailbox destination: ") ),
 			)
@@ -610,7 +690,7 @@ function drawAdminTools_Emails($domain){
 			"check" => "email",
 			"can_be_empty" => "yes",
 			"empty_makes_sql_null" => "yes",
-			"legend" => _("Redirection 1: ") );
+			"legend" => _("Redirection 2: ") );
 		$dsc["cols"]["localdeliver"] = array(
 			"type" => "checkbox",
 			"values" => array( "yes","no"),
