@@ -94,7 +94,7 @@ $txt .= "<tr><td>&nbsp;</td><td><input type=\"submit\" name=\"modifylistdata\" v
 	<input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
 	<input type=\"hidden\" name=\"edit_domain\" value=\"$edit_domain\">
 	<input type=\"hidden\" name=\"whatdoiedit\" value=\"mails\">
-	<div onmouseover=\"return escape('"._("List name") ."')\">". _("List owner") ."</div></td>
+	<div onmouseover=\"return escape('"._("List name") ."')\">". _("List name:") ."</div></td>
 	<td><input type=\"text\" name=\"newlist_name\" value=\"\"></td></tr>
 	<tr><td align=\"right\"><div onmouseover=\"return escape('". _("This is the main owner of the list.") ."')\">". _("List owner:") ."</div></td>
 	<td><input type=\"text\" name=\"newlist_owner\" value=\"\">";
@@ -111,7 +111,6 @@ $txt .= "</td></tr>
 	}
 	$txt .= "</b></font></font>";
 	
-	$txt .= "<script language=\"JavaScript\" type=\"text/javascript\" src=\"gfx/wz_tooltip.js\"></script>";
 	return $txt;
 }
 
@@ -231,12 +230,12 @@ function getTunableHelp($tunable_name){
 	case "noaccessdenymails":
 		$hlp .= _("Help missing for noaccessdenymails") ;
 		break;
-	case "memorymailsize":
-		$hlp .= _("Here is specified in bytes how big a mail can be and still be prepared for sending in memory. It\'s greatly reducing the amount of write system calls to prepare it in memory before sending it, but can also lead to denial of service attacks. Default is 16k (16384 bytes).") ;
-		break;
 	case "relayhost":
 		$hlp .= _("Mail server used to send the messages.") ;
 		break;
+	case "memorymailsize":
+		$hlp .= _("Here is specified in bytes how big a mail can be and still be prepared for sending in memory. It\'s greatly reducing the amount of write system calls to prepare it in memory before sending it, but can also lead to denial of service attacks. Default is 16k (16384 bytes).") ;
+		break;
 	case "verp":
 		$hlp .= _("Enable VERP support.") ;
 		break;
@@ -388,6 +387,8 @@ function list_options(){
 
 	global $edit_domain;
 	global $adm_login;
+	global $conf_use_advanced_lists_tunables;
+
 	$admin_path = getAdminPath($adm_login);
 	$list_path = $admin_path."/".$edit_domain."/lists/".$edit_domain."_".$_REQUEST["edit_mailbox"];
 
@@ -425,12 +426,20 @@ function list_options(){
 
 	$output .= "<tr><td colspan=\"2\"><b>". _("SMTP configuration") ."</b></td></tr>";
 	$output .= getListOptionsValue($list_path,"memorymailsize", _("Max mail memory size:") );
-	$output .= getListOptionsValue($list_path,"relayhost", _("SMTP relay server:") );
-	$output .= getListOptionsValue($list_path,"verp", _("VERP:") );
-	$output .= getListOptionsValue($list_path,"maxverprecips", _("Max VERP recipients:") );
-	$output .= getListOptionsValue($list_path,"delimiter", _("Delimiter:") );
-	$output .= getListOptionsValue($list_path,"bouncelife", _("Bounce life:") );
-	$output .= getListOptionsTextarea($list_path,"access", _("Access list:") );
+	if($conf_use_advanced_lists_tunables == "yes"){
+		$output .= getListOptionsValue($list_path,"relayhost", _("SMTP relay server:") );
+		$output .= getListOptionsValue($list_path,"verp", _("VERP:") );
+		$output .= getListOptionsValue($list_path,"maxverprecips", _("Max VERP recipients:") );
+		$output .= getListOptionsValue($list_path,"delimiter", _("Delimiter:") );
+		$output .= getListOptionsValue($list_path,"bouncelife", _("Bounce life:") );
+		$output .= getListOptionsTextarea($list_path,"access", _("Access list:") );
+	}
+
+	$output .= "<tr><td colspan=\"2\"><b>". _("Subscribe/Unsubscribe an email address") ."</b></td></tr>";
+	$output .= "<tr><td onmouseover=\"Tip('". _("Insert here an email address to subscribe it.") ."',STICKY,true,CLICKCLOSE,true,FADEIN,600)\" valign=\"top\" align=\"right\">". _("Subscribe:") ."</td>
+    <td><input size=\"40\" type=\"text\" value=\"\" name=\"sub\"></td></tr>";
+	$output .= "<tr><td onmouseover=\"Tip('". _("Insert here an email address to unsubscribe it.") ."',STICKY,true,CLICKCLOSE,true,FADEIN,600)\" valign=\"top\" align=\"right\">". _("Unsubscribe:") ."</td>
+    <td><input size=\"40\" type=\"text\" value=\"\" name=\"unsub\"></td></tr>";
 
 	$output .= "<tr><td colspan=\"2\"><b>". _("Web archive") ."</b></td></tr>";
 	$output .= getListOptionsWABoolean("webarchive", _("Enable webarchive:") );
