@@ -121,7 +121,7 @@ function drawEditAdmin($admin){
 	$prodsid .= "</select>";
 
 	$user_data .= dtcFormLineDraw( _("Path:") ,"<input class=\"dtcDatagrid_input_alt_color\" type=\"text\" name=\"changed_path\" value=\"$adm_path\">",0);
-	$user_data .= dtcFormLineDraw( _("Client ID:") ,"<input class=\"dtcDatagrid_input_color\" type=\"text\" name=\"changed_id_client\" value=\"$adm_id_client\"><a href=\"?rub=crm&id=$adm_id_client\">client</a>");
+	$user_data .= dtcFormLineDraw( _("Client ID:") ,"<input class=\"dtcDatagrid_input_color\" type=\"text\" name=\"changed_id_client\" value=\"$adm_id_client\"><a href=\"?rub=crm&id=$adm_id_client\">"._("client")."</a>");
 	$user_data .= dtcFormLineDraw( _("Disk quota (MB):") ,"<input class=\"dtcDatagrid_input_alt_color\" type=\"text\" name=\"adm_quota\" value=\"$adm_quota\">",0);
 	$user_data .= dtcFormLineDraw( _("Allowed bandwidth per month (MB):") ,"<input class=\"dtcDatagrid_input_color\" type=\"text\" name=\"bandwidth_per_month\" value=\"$bandwidth_per_month_mb\">");
 	$user_data .= dtcFormLineDraw( _("Expiry date:") ,"<input class=\"dtcDatagrid_input_alt_color\" type=\"text\" name=\"expire\" value=\"$expire\">",0);
@@ -184,7 +184,7 @@ function drawEditAdmin($admin){
 </div></td></tr></table></form>";
 
 	// Deletion of VPS
-	$q = "SELECT * FROM $pro_mysql_vps_table WHERE owner='$adm_login';";
+	$q = "SELECT * FROM $pro_mysql_vps_table WHERE owner='$adm_login' ORDER BY vps_server_hostname,vps_xen_name;";
 	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	if($n > 0){
@@ -285,7 +285,7 @@ function drawEditAdmin($admin){
 	$out = "<font size=\"-1\">
 <table>
  <tr>
-  <td>$domain_conf</td><td background=\"gfx/skin/frame/border_2.gif\">&nbsp;</td>
+  <td>$domain_conf</td><td background=\"gfx/border_2.gif\">&nbsp;</td>
   <td>$user_data</td>
  </tr>
 </table>
@@ -348,16 +348,19 @@ function drawDomainConfig($admin){
 					"text" => _("Customize") ),
 				"safe_mode" => array(
 					"type" => "checkbox",
+					"help" => _("This will add a new subdomain switch yes/no in the client interface of this domain. Unticking this checkbox is NOT ENOUGH to disable the safe mode. Please go in the subdomains section of this domain name to finish the setup."),
 					"legend" => _("PHP safe_mode"),
 					"values" => array("yes","no"),
 					"display_replace" => array( _("No") , _("Yes") )),
 				"sbox_protect" => array(
 					"type" => "checkbox",
+					"help" => _("This will add a new subdomain switch yes/no in the client interface of this domain. Unticking this checkbox is NOT ENOUGH to disable the sbox CGI-BIN protection. Please go in the subdomains section of this domain name to finish the setup."),
 					"legend" => _("CGI-BIN protection") ,
 					"values" => array("yes","no"),
 					"display_replace" => array(_("No"),_("Yes"))),
 				"quota" => array(
 					"type" => "text",
+					"help" => _("Quota disk in MBytes"),
 					"legend" => _("Disk quota") ,
 					"size" => "6"),
 				"max_email" => array(
@@ -461,6 +464,7 @@ function drawDomainConfig($admin){
 			"skip_deletion" => "yes",
 			"skip_creation" => "yes",
 			"where_condition" => "owner='$adm_login'",
+			"order_by" => "vps_server_hostname,vps_xen_name",
 			"cols" => array(
 				"id" => array(
 					"type" => "id",
@@ -475,23 +479,28 @@ function drawDomainConfig($admin){
 				"start_date" => array(
 					"type" => "text",
 					"size" => "10",
+					"help" => _("Format: YYYY-MM-DD."),
 					"legend" => _("Registration") ),
 				"expire_date" => array(
 					"type" => "text",
+					"help" => _("Format: YYYY-MM-DD."),
 					"size" => "10",
 					"legend" => _("Expiration") ),
 				"hddsize" => array(
 					"type" => "text",
+					"help" => _("Hard drive space in MBytes. You will need to manually do a lvresize on the dom0 of your VPS server to activate the changes."),
 					"size" => "5",
 					"legend" => "HDD"),
 				"ramsize" => array(
 					"type" => "text",
+					"help" => _("Memory size in MBytes. You will need to manually change the RAM size in the /etc/xen/xenXX startup configuration file and reboot the VPS to activate the changes."),
 					"size" => "5",
 					"legend" => "RAM"),
 				"bandwidth_per_month_gb" => array(
 					"type" => "text",
 					"size" => "5",
-					"legend" => _("Bandwidth per month") ),
+					"help" => _("Bandwidth per month in MBytes."),
+					"legend" => _("Bandwidth") ),
 				"product_id" => array(
 					"type" => "popup",
 					"legend" => _("Product ID") ,
@@ -534,26 +543,31 @@ function drawDomainConfig($admin){
 					"display" => "no",
 					"legend" => "id"),
 				"server_hostname" => array(
-					"type" => "info",
+					"type" => "text",
 					"legend" => _("Server name") ),
 				"start_date" => array(
 					"type" => "text",
+					"help" => _("Format: YYYY-MM-DD."),
 					"size" => "10",
 					"legend" => _("Registration") ),
 				"expire_date" => array(
 					"type" => "text",
+					"help" => _("Format: YYYY-MM-DD."),
 					"size" => "10",
 					"legend" => _("Expiration") ),
 				"hddsize" => array(
 					"type" => "text",
+					"help" => _("Hard drive size in MBytes."),
 					"size" => "5",
 					"legend" => "HDD"),
 				"ramsize" => array(
 					"type" => "text",
+					"help" => _("Memory size in MBytes."),
 					"size" => "5",
 					"legend" => "RAM"),
 				"bandwidth_per_month_gb" => array(
 					"type" => "text",
+					"help" => _("Bandwidth per month in GBytes."),
 					"size" => "5",
 					"legend" => _("Bandwidth per month") ),
 				"country_code" => array(
