@@ -17,12 +17,17 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "add_dbuser"){
 		$submit_err .= _("Incorrect MySQL login format: please don't enter root or debian-sys-maint") ."<br>\n";
 		$commit_flag = "no";
 	}
+	if($conf_user_mysql_prepend_admin_name == "yes"){
+		$dbuser = $adm_login . "-" . $_REQUEST["dbuser"];
+	}else{
+		$dbuser = $_REQUEST["dbuser"];
+	}
 	if(!isDTCPassword($_REQUEST["db_pass"])){
 		$submit_err .= _("Password must consist of only letters and numbers (a-zA-Z0-9) and should be between 6 and 16 chars long.") ."<br>\n";
 		$commit_flag = "no";
 	}
 	if($commit_flag == "yes"){
-		$query = "SELECT * FROM mysql.user WHERE User='".$_REQUEST["dbuser"]."';";
+		$query = "SELECT * FROM mysql.user WHERE User='".$dbuser."';";
 		$result = mysql_query($query)or die("Cannot execute query \"$query\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 		$num_rows = mysql_num_rows($result);
 		if($num_rows > 0){
@@ -32,10 +37,10 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "add_dbuser"){
 	}
 	if($commit_flag == "yes"){
 		$q = "INSERT INTO mysql.user (Host,User,Password,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv,Reload_priv,Shutdown_priv,Process_priv,File_priv,Grant_priv,References_priv,Index_priv,Alter_priv,dtcowner)
-			VALUES ('%','".$_REQUEST["dbuser"]."',Password('".$_REQUEST["db_pass"]."'),'N','N','N','N','N','N','N','N','N','N','N','N','N','N','$adm_login');";
+			VALUES ('%','".$dbuser."',Password('".$_REQUEST["db_pass"]."'),'N','N','N','N','N','N','N','N','N','N','N','N','N','N','$adm_login');";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 		$q = "INSERT INTO mysql.user (Host,User,Password,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv,Reload_priv,Shutdown_priv,Process_priv,File_priv,Grant_priv,References_priv,Index_priv,Alter_priv,dtcowner)
-			VALUES ('localhost','".$_REQUEST["dbuser"]."',Password('".$_REQUEST["db_pass"]."'),'N','N','N','N','N','N','N','N','N','N','N','N','N','N','$adm_login');";
+			VALUES ('localhost','". $dbuser ."',Password('".$_REQUEST["db_pass"]."'),'N','N','N','N','N','N','N','N','N','N','N','N','N','N','$adm_login');";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 	}
 	if($conf_user_mysql_type=="distant"){
@@ -54,7 +59,12 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "add_dbuser_db"){
 		$submit_err .= _("This is not a valid database name! Please choose another one.") ."<br>\n";
 		$commit_flag = "no";
 	}else{
-		$q = "SELECT * FROM mysql.db WHERE Db='".$_REQUEST["newdb_name"]."';";
+		if($conf_user_mysql_prepend_admin_name == "yes"){
+			$newdb_name = $adm_login . "_" . $_REQUEST["newdb_name"];
+		}else{
+			$newdb_name = $_REQUEST["newdb_name"];
+		}
+		$q = "SELECT * FROM mysql.db WHERE Db='". $newdb_name ."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 		$num_rows = mysql_num_rows($r);
 		if($num_rows > 0){
@@ -75,13 +85,13 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "add_dbuser_db"){
 		}
 	}
 	if($commit_flag == "yes"){
-		$q = "CREATE DATABASE ".$_REQUEST["newdb_name"].";";
+		$q = "CREATE DATABASE IF NOT EXISTS `". $newdb_name ."`;";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
-		$q = "INSERT INTO mysql.db ( Host,Db,User,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv,Grant_priv,References_priv,Index_priv,Alter_priv,Lock_tables_priv)
-		VALUES ('%','".$_REQUEST["newdb_name"]."','".$_REQUEST["dbuser"]."','Y','Y','Y','Y','Y','Y','N','Y','Y','Y','Y');";
+		$q = "INSERT INTO mysql.db ( Host,Db,User,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv,Grant_priv,References_priv,Index_priv,Alter_priv,Lock_tables_priv,Create_tmp_table_priv,Create_view_priv,Show_view_priv)
+		VALUES ('%','". $newdb_name ."','".$_REQUEST["dbuser"]."','Y','Y','Y','Y','Y','Y','N','Y','Y','Y','Y','Y','Y','Y');";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
-		$q = "INSERT INTO mysql.db ( Host,Db,User,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv,Grant_priv,References_priv,Index_priv,Alter_priv,Lock_tables_priv)
-		VALUES ('localhost','".$_REQUEST["newdb_name"]."','".$_REQUEST["dbuser"]."','Y','Y','Y','Y','Y','Y','N','Y','Y','Y','Y');";
+		$q = "INSERT INTO mysql.db ( Host,Db,User,Select_priv,Insert_priv,Update_priv,Delete_priv,Create_priv,Drop_priv,Grant_priv,References_priv,Index_priv,Alter_priv,Lock_tables_priv,Create_tmp_table_priv,Create_view_priv,Show_view_priv)
+		VALUES ('localhost','". $newdb_name ."','".$_REQUEST["dbuser"]."','Y','Y','Y','Y','Y','Y','N','Y','Y','Y','Y','Y','Y','Y');";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 		$q = "FLUSH PRIVILEGES;";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
@@ -100,11 +110,11 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "modify_dbuser_pass"){
 	}
 	// action=modify_dbuser_pass&dbuser=zigo&db_pass=bla
 	if(!isFtpLogin($_REQUEST["dbuser"])){
-		$submit_err .= $txt_dbsql_incorrect_db_login_form[$lang]."<br>\n";
+		$submit_err .= _("Incorrect MySQL db format: please enter another login and try again.")."<br>\n";
 		$commit_flag = "no";
 	}
 	if(!isDTCPassword($_REQUEST["db_pass"])){
-		$submit_err .= $txt_dbsql_password_are_made_only_with_standards_chars_and_numbers_and_size[$lang]."<br>\n";
+		$submit_err .= _("Incorrect MySQL password format: please enter another login and try again.")."<br>\n";
 		$commit_flag = "no";
 	}
 	if($commit_flag == "yes"){
@@ -112,7 +122,7 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "modify_dbuser_pass"){
 		$result = mysql_query($query)or die("Cannot execute query \"$query\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 		$num_rows = mysql_num_rows($result);
 		if($num_rows < 1){
-			$submit_err .= $txt_dbsql_no_db_user_by_that_name_exists_in_the_db[$lang]."<br>\n";
+			$submit_err .= _("A MySQL user by that name already exists. Please choose another one.")."<br>\n";
 			$commit_flag = "no";
 		}
 	}
@@ -134,7 +144,7 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "del_dbuser"){
 	}
 	// action=del_dbuser&dbuser=zigo
 	if(!isFtpLogin($_REQUEST["dbuser"])){
-		$submit_err .= $txt_dbsql_incorrect_db_login_form[$lang]."<br>\n";
+		$submit_err .= _("Incorrect db login form")."<br>\n";
 		$commit_flag = "no";
 	}else{
 		$q = "SELECT * FROM mysql.db WHERE User='".$_REQUEST["dbuser"]."';";
@@ -186,7 +196,7 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "delete_user_db"){
 	if($commit_flag == "yes"){
 		$q = "DELETE FROM mysql.db WHERE Db='".$_REQUEST["dbname"]."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
-		$q = "DROP DATABASE ".$_REQUEST["dbname"].";";
+		$q = "DROP DATABASE IF EXISTS ".$_REQUEST["dbname"].";";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 		$q = "FLUSH PRIVILEGES;";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
@@ -204,7 +214,7 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "change_db_owner"){
 	}
 	// action=change_db_owner&dbname=clem&dbuser=zigo
 	if(!isFtpLogin($_REQUEST["dbuser"])){
-		$submit_err .= $txt_dbsql_incorrect_db_login_form[$lang]."<br>\n";
+		$submit_err .= _("Incorrect MySQL login format: please enter another login and try again.")."<br>\n";
 		$commit_flag = "no";
 	}
 	if(!isDatabase($_REQUEST["dbname"])){
@@ -240,37 +250,4 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "change_db_owner"){
 	}
 }
 
-if(isset($_REQUEST["change_mysql_password"]) && $_REQUEST["change_mysql_password"] == "Ok"){
-	checkLoginPass($adm_login,$adm_pass);
-	if($conf_user_mysql_type=="distant"){
-		$newid=mysql_connect($conf_user_mysql_host,$conf_user_mysql_root_login,$conf_user_mysql_root_pass) or die("Cannot connect to user SQL host");
-	}
-	$query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login' AND (adm_pass='$adm_pass' OR (pass_next_req='$adm_pass' AND pass_expire > '".mktime()."'));";
-	$result = mysql_query($query)or die("Cannot execute query \"$query\" !!!".mysql_error());
-	$num_rows = mysql_num_rows($result);
-	if($num_rows != 1){
-		$submit_err .= _("User or password is incorrect!") ."<br>\n";
-		$commit_flag = "no";
-	}
-
-	if($commit_flag == "yes"){
-		if(!isDTCPassword($_REQUEST["new_mysql_password"])){
-			$submit_err .= $txt_dbsql_password_are_made_only_with_standards_chars_and_numbers_and_size[$lang]."<br>\n";
-			$commit_flag = "no";
-		}
-	}
-
-	if($commit_flag == "yes"){
-		mysql_select_db("mysql")or die("Cannot select db mysql for account management !!!");
-		$query = "UPDATE user SET Password=PASSWORD('".$_REQUEST["new_mysql_password"]."') WHERE User='$adm_login';";
-		mysql_query($query)or die("Cannot execute query \"$query\" !!!".mysql_error());
-		mysql_query("FLUSH PRIVILEGES");
-		mysql_select_db($conf_mysql_db)or die("Cannot select db \"$conf_mysql_db\" !!!");
-	}
-	if($conf_user_mysql_type=="distant"){
-		mysql_close($newid) or die("Cannot disconnect to user database");
-		connect2base();
-	}
-}
-
 ?>
