@@ -176,6 +176,10 @@ if(isset($_REQUEST["addnewlisttodomain"]) && $_REQUEST["addnewlisttodomain"] ==
 	fwrite($fp3,$newLine3);
 	fclose($fp3);
 
+	// Adds a subonlyget tunable by default
+	$command = "touch $list_full_path/control/subonlyget";
+	exec($command);
+
 	if (!ereg("\@", $owner)){
 		$owner .= "@" . $edit_domain;
 	}
@@ -213,16 +217,17 @@ if(isset($_REQUEST["addnewlisttodomain"]) && $_REQUEST["addnewlisttodomain"] ==
 	$msg = str_replace("#name#",$name, _("You can control your mailing list by email or by control panel.
 You can send a email to the following addresses to execute the listed command:
   
-  #name#-help@#domain# -> return the most common list's commands
-  #name#-list@#domain# -> return the subscribers's list
-  #name#-get-N@#domain# -> return the N list's message
-  #name#-owner@#domain# -> you can contact the list's owner by this address
-  #name#-unsubscribe@#domain# -> unsubscribe the email's sender from the list
-  #name#-subscribe@#domain# -> subscribe the email's sender to the list
-  #name#-subscribe-digest@#domain# -> subscribe the email's sender to the list's digest version
-  #name#-subscribe-nomail@#domain# -> subscribe the email's sender to the list's nomail version
+  #name##DELIMITER#help@#domain# -> return the most common list's commands
+  #name##DELIMITER#list@#domain# -> return the subscribers's list
+  #name##DELIMITER#get-N@#domain# -> return the N list's message
+  #name##DELIMITER#owner@#domain# -> you can contact the list's owner by this address
+  #name##DELIMITER#unsubscribe@#domain# -> unsubscribe the email's sender from the list
+  #name##DELIMITER#subscribe@#domain# -> subscribe the email's sender to the list
+  #name##DELIMITER#subscribe-digest@#domain# -> subscribe the email's sender to the list's digest version
+  #name##DELIMITER#subscribe-nomail@#domain# -> subscribe the email's sender to the list's nomail version
   
 For more informations go to mlmmj official web site at http://mlmmj.mmj.dk") );
+	$msg = str_replace("#DELIMITER#",$conf_recipient_delimiter,$msg);
 	$msg = str_replace("#domain#",$edit_domain,$msg);
 	$headers = "FROM: $conf_webmaster_email_addr\n";
 	$headers .= "Return-Path: $conf_webmaster_email_addr\n";
@@ -248,21 +253,12 @@ function tunablesBooleanRequestCheck($ctrl_path,$tunable_name){
 	}
 }
 
-function tunablesValueRequestCheck($ctrl_path,$tunable_name,$regexp=""){
-	$option_file = $ctrl_path."/".$tunable_name;
+function tunablesValueRequestCheck($ctrl_path,$tunable_name){
+$option_file = $ctrl_path."/".$tunable_name;
 	if ($_REQUEST[$tunable_name]!=""){
 		//i write in the file
-		$fp = fopen($option_file,"w+");
-		if($fp != NULL){
-			if($regexp!=""){
-				if( preg_match($regexp,$_REQUEST[$tunable_name]) ){
-					fwrite($fp,$_REQUEST[$tunable_name]."\n");
-				}
-			}else{
-				fwrite($fp,$_REQUEST[$tunable_name]."\n");
-			}
-			fclose($fp);
-		}
+		$write_line = "echo ".$_REQUEST[$tunable_name]." > ".$option_file;
+		exec($write_line);
 	}else{ //i remove the file
 		if (file_exists($option_file)){
 		$rem = "rm ".$option_file;
@@ -271,27 +267,19 @@ function tunablesValueRequestCheck($ctrl_path,$tunable_name,$regexp=""){
 	}
 }
 
-function tunablesListRequestCheck($ctrl_path,$tunable_name,$regexp=""){
+function tunablesListRequestCheck($ctrl_path,$tunable_name){
 	$option_file = $ctrl_path."/".$tunable_name;
 	if (file_exists($option_file) && ($tunable_name!="owner")){
 		$rem = "rm ".$option_file;
 		exec($rem);
 	} 		
-	$fp = fopen($option_file,"w+");
-	if($fp != NULL){
-		for($i=0;$i<sizeof($_REQUEST[$tunable_name]);$i++){
-			if ($_REQUEST[$tunable_name][$i]!=""){
-				if($regexp!=""){
-					if( preg_match($regexp,$_REQUEST[$tunable_name][$i]) ){
-						fwrite($fp,$_REQUEST[$tunable_name][$i]."\n");
-					}
-				}else{
-					fwrite($fp,$_REQUEST[$tunable_name][$i]."\n");
-				}
-			}
+	for($i=0;$i<sizeof($_REQUEST[$tunable_name]);$i++){
+		if ($_REQUEST[$tunable_name][$i]!=""){
+			$write_line = "echo ".$_REQUEST[$tunable_name][$i]." >> ".$option_file;
+			exec($write_line);
 		}
-		fclose($fp);
 	}
+	
 }
 
 function tunablesTextareaRequestCheck($ctrl_path,$tunable_name){
@@ -311,6 +299,20 @@ function tunablesTextareaRequestCheck($ctrl_path,$tunable_name){
 	}
 }
 
+function tunablesSUBTextareaRequestCheck($list_dir,$tunable_name){
+$email = $_REQUEST[$tunable_name];
+//must add $email validation!!!
+$command = "/usr/bin/mlmmj-sub -L ".$list_dir."/ -a ".$email;
+exec($command);
+}
+
+function tunablesUNSUBTextareaRequestCheck($list_dir,$tunable_name){
+$email = $_REQUEST[$tunable_name];
+//must add $email validation!!!
+$command = "/usr/bin/mlmmj-unsub -L ".$list_dir."/ -a ".$email;
+exec($command);
+}
+
 function tunablesWABooleanRequestCheck($list_dir,$tunable_name){
 	global $adm_login;
 	global $pro_mysql_list_table;
@@ -448,7 +450,7 @@ if(isset($_REQUEST["modifylistdata"]) && $_REQUEST["modifylistdata"] == "Ok"){
 	// 1 closedlist
 	tunablesBooleanRequestCheck($ctrl_dir,"closedlist");
 	tunablesBooleanRequestCheck($ctrl_dir,"moderated");
-	tunablesListRequestCheck($ctrl_dir,"moderators","/(^([a-zA-Z0-9])|^([a-zA-Z0-9]+)([._a-zA-Z0-9-]*))@([a-z0-9]+)([-a-z0-9.]*)\.([a-z0-9-]*)([a-z0-9]+)\$/");
+	tunablesListRequestCheck($ctrl_dir,"moderators");
 	tunablesBooleanRequestCheck($ctrl_dir,"subonlypost");
 	tunablesBooleanRequestCheck($ctrl_dir,"notifysub");
 	tunablesBooleanRequestCheck($ctrl_dir,"nosubconfirm");
@@ -461,17 +463,23 @@ if(isset($_REQUEST["modifylistdata"]) && $_REQUEST["modifylistdata"] == "Ok"){
 	tunablesBooleanRequestCheck($ctrl_dir,"noaccessdenymails");
 	tunablesBooleanRequestCheck($ctrl_dir,"nosubonlydenymails");
 	tunablesValueRequestCheck($ctrl_dir,"prefix");
-	tunablesValueRequestCheck($ctrl_dir,"verp");
-	tunablesValueRequestCheck($ctrl_dir,"maxverprecips","/^([0-9]+)\$/");
-	tunablesValueRequestCheck($ctrl_dir,"delimiter","/^([+-])\$/");
-	tunablesValueRequestCheck($ctrl_dir,"bouncelife","/^([0-9]+)\$/");
-	tunablesTextareaRequestCheck($ctrl_dir,"access");
-	tunablesValueRequestCheck($ctrl_dir,"digestinterval","/^([0-9]+)\$/");
-	tunablesValueRequestCheck($ctrl_dir,"digestmaxmails","/^([0-9]+)\$/");
-	tunablesListRequestCheck($ctrl_dir,"owner","/(^([a-zA-Z0-9])|^([a-zA-Z0-9]+)([._a-zA-Z0-9-]*))@([a-z0-9]+)([-a-z0-9.]*)\.([a-z0-9-]*)([a-z0-9]+)\$/");
+	tunablesValueRequestCheck($ctrl_dir,"memorymailsize");
+	if($conf_use_advanced_lists_tunables == "yes"){
+		tunablesValueRequestCheck($ctrl_dir,"relayhost");
+		tunablesValueRequestCheck($ctrl_dir,"verp");
+		tunablesValueRequestCheck($ctrl_dir,"maxverprecips");
+		tunablesValueRequestCheck($ctrl_dir,"delimiter");
+		tunablesValueRequestCheck($ctrl_dir,"bouncelife");
+		tunablesTextareaRequestCheck($ctrl_dir,"access");
+	}
+	tunablesValueRequestCheck($ctrl_dir,"digestinterval");
+	tunablesValueRequestCheck($ctrl_dir,"digestmaxmails");
+	tunablesListRequestCheck($ctrl_dir,"owner");
 	tunablesTextareaRequestCheck($ctrl_dir,"customheaders");
 	tunablesListRequestCheck($ctrl_dir,"delheaders");
 	tunablesTextareaRequestCheck($ctrl_dir,"footer");
+	tunablesSUBTextareaRequestCheck($list_dir, "sub");
+	tunablesUNSUBTextareaRequestCheck($list_dir, "unsub");
 	tunablesWABooleanRequestCheck($list_dir,"webarchive");
 	tunablesTextareaRequestCheck($list_dir,"rcfile");
 	tunablesWABooleanRequestCheck($ctrl_dir,"spammode");
