@@ -23,7 +23,7 @@ function connectToVPSServer($vps_node){
 	}
 	$a = mysql_fetch_array($r);
 	$port = 8089;
-	$soap_client = new nusoapclient("https://$vps_node:$port/");
+	$soap_client = new nusoap_client("https://$vps_node:$port/");
 	$err = $soap_client->getError();
 	if($err){
 		echo "Error: ".$err;
@@ -56,12 +56,22 @@ function isVPSNodeLVMEnabled($vps_node){
 	}
 }
 
+function getVPSIso($vps_node,$vps_name,$soap_client){
+	global $vps_soap_err;
+	$r = $soap_client->call("reportInstalledIso",array("vpsname" => "xen".$vps_name),"","","");
+	$err = $soap_client->getError();
+	if($err){
+		$vps_soap_err = _("Could not get installed .iso files. Error: ").$err;
+	}
+	return $r;
+}
+
 function getVPSInfo($vps_node,$vps_name,$soap_client){
 	global $vps_soap_err;
 	$r = $soap_client->call("getVPSState",array("vpsname" => "xen".$vps_name),"","","");
 	$err = $soap_client->getError();
 	if($err){
-		$vps_soap_err = "Could not get virtual machine info. Error: ".$err;
+		$vps_soap_err = _("Could not get virtual machine info. Error: ").$err;
 		return false;
 	}else{
 		$out = array();
@@ -139,4 +149,16 @@ function getInstallableOS($soap_client){
 	}
 }
 
+function getInstallableAPP($soap_client){
+	global $vps_soap_err;
+	$r = $soap_client->call("getInstallableAPP",array(),"","","");
+	$err = $soap_client->getError();
+	if($err){
+		$vps_soap_err = "Could not get installable APP data. Error: ".$err;
+		return false;
+	}else{
+		return $r;
+	}
+}
+
 ?>
